/*
 *--- Colorer.c -----------------------------------------------------------
 *: plug-in Example Source File
 *
 * ABSTRACT:
 *
 * This routine does the following:
 * 		1) Records PageMaker's current state
 * 		2) Creates a Dialog box for the user to specify several parameters
 * 		3) Colors various PageMaker Objects according to those parameters
 * 		4) Returns PageMaker to its previous state
 *
 * This example plug-in illustrates working with:
 *		Dialogs
 *		Commands and Queries
 *		PageMaker objects
 *		Parameter packing and unpacking
 *--------------------------------------------------------------------------
 */
						
#include <string.h>
#include "PMPlugin.h"

#ifdef MACINTOSH
	#if __MWERKS__ && __MC68K__
		#include <A4Stuff.h>
		#include <SetUpA4.h>
	#endif
	#include "WinTypes.h"
#endif
#ifdef WINDOWS
	#include <Windows.h>
#endif
#include "Colorer.h"
#include "CUtils.h"

//--- Global variables ----------------------------------------
/* ---------------- Definitions ---------------- */
#define SUCCESS			1
#define FAILURE			0
#define STAYINMEMORY	-1

/* ---------------- PageMaker (New)SDK include files ---------------- */
#include "CIInterfaceManager.h"
#include "PMEvent.h"

#include "PMEventRec.h"
#include "CIBasic.h"
#include "PMInterfaceIDs.h"
#include "CICommandsAndQueries.h"
#include "CIObjectAccess.h"
#include "PMUtils.h"

#ifdef WINDOWS
	extern PMHandle hDllInstance;
#endif

PMXErr DoInvoke( PMMessage *pMsg );
PMXErr DoLoad(PMMessage* pMsg);
PMXErr DoRegister(PMMessage* pMsg);
PMXErr DoInvoke(PMMessage* pMsg);
PMXErr DoEvent(PMMessage* pMsg);
PMXErr DoSysEvent(PMMessage* pMsg);
PMXErr DoAcquireInterface(PMMessage* pMsg);
PMXErr DoReleaseInterface( PMMessage *pMsg );
PMXErr DoUnload(PMMessage* pMsg);
PMXErr DoShutdown(PMMessage* pMsg);
PMXErr DoCleanup(PMMessage* pMsg);

#ifdef MACINTOSH
	#ifdef powerc
		#pragma export on
	#endif
		PMXErr main(PMMessage *pMsg);
	#ifdef powerc
		#pragma export off
	#endif
#else
	BOOL WINAPI DllMain (HINSTANCE hDLL, DWORD dwReason, LPVOID pReserved);
#endif

sPMParamBlockPtr gPB = NULL;
sPMParamBlockPtr thePB = NULL;
CIInterfaceManager	*gpIntfMgr = (CIInterfaceManager *) NULL;
CICommandQuery *gpCmdQry = (CICommandQuery *)NULL;

#ifdef WINDOWS
BOOL WINAPI DllMain (HINSTANCE hDLL, DWORD dwReason, LPVOID pReserved)
{
	hDllInstance = hDLL;

	return TRUE;
}
#endif //WINDOWS

static void  ConvertParameters(sPMParamBlockPtr thePB, PMBool bDoubleSided, PMBool *doRectangles, PMBool *doOvals, PMBool *doLines, short *firstPage, short *lastPage, char *colorString);
static PMBool  ColorObjects(sPMParamBlockPtr thePB, PMBool bDoubleSided);
static PMBool  GetDefaultColor(sPMParamBlockPtr thePB, char *defaultColor);

/*
 *--- main --------------------------------------------------------------------
 *  Entry point for plug-in control tasks.
 *-----------------------------------------------------------------------------
 */ 
PMXErr main(PMMessage *pMsg)
{
	PMXErr	result;
#if __MWERKS__ && __MC68K__
	long oldA4 = SetCurrentA4();
	RememberA4();
#endif

	gpIntfMgr = pMsg->pInterfaceMgr;
	
	switch ( pMsg->opCode ) {
		case kPMLoad: 
			result = DoLoad(pMsg);
			break;

		case kPMRegister: 
			result = DoRegister(pMsg);
			break;
			
		case kPMInvoke: 
			result = DoInvoke(pMsg);
			break;

		case kPMEvent: 
			result = DoEvent(pMsg);
			break;
			
		case kPMSysEvent: 
			result = DoSysEvent(pMsg);
			break;
			
		case kPMAcquireInterface: 
			result = DoAcquireInterface(pMsg);
			break;
			
		case kPMReleaseInterface: 
			result = DoReleaseInterface(pMsg);
			break;
			
		case kPMUnload: 
			result = DoUnload(pMsg);
			break;

		case kPMShutdown: 
			result = DoShutdown(pMsg);
			break;
			
		case kPMCleanup: 
			result = DoCleanup(pMsg);
			break;
			
		default: 
			result = 0;
	}

#if __MWERKS__ && __MC68K__
	SetA4(oldA4);
#endif

	return result;
}
/*
 *--- DoRegister --------------------------------------------------------------
 *  Called if Plug-in registers for Events or adds new interfaces to PM.
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoRegister( PMMessage *pMsg )
{
	PMXErr 	result = SUCCESS;

	gpIntfMgr = pMsg->pInterfaceMgr;

	return result;
}

/*
 *--- DoAcquireInterface ------------------------------------------------------
 *  Called when other plug-ins acquire the exported interface.
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoAcquireInterface( PMMessage *pMsg )
{
	PMXErr result = SUCCESS;

	gpIntfMgr = pMsg->pInterfaceMgr;

	return result;
}

/*
 *--- DoReleaseInterface ------------------------------------------------------
 *  Called when other plug-ins release the acquired interface.
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoReleaseInterface( PMMessage *pMsg )
{
	PMXErr result = SUCCESS;

	gpIntfMgr = pMsg->pInterfaceMgr;
			
	return result;
}

/*
 *--- DoInvoke ----------------------------------------------------------------
 *  
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoInvoke( PMMessage *pMsg )
{
	PMXErr rc = SUCCESS;
	short rememberPage;
	PMBool bDoubleSided, bFacingPages;

	gpIntfMgr = pMsg->pInterfaceMgr;

	if (!gpIntfMgr->AcquirePMInterface(PMIID_CMDQRY, (LPVOID *)&gpCmdQry))
		gpCmdQry->Retrieve (&thePB);
	else
		return FAILURE;

	if (DoShortQuery(thePB, pm_getpmstate) == 1) // check for no open publication
	{
		BuildErrorMessages(thePB, "No publication is open.", "");

		rc = CQ_INVALID_STATE;
		goto onErr;
	}
	//  remember user's current page
	rememberPage = DoShortQuery(thePB, pm_getpagenumber);
	// remember page setup
	rc = GetPageOptions(thePB, &bDoubleSided, &bFacingPages);
	if (rc != CQ_SUCCESS) goto onErr;

	rc = DoDialog(thePB);
	if (rc)
	{
		// this plug-in needs double-sided to be OFF
		rc = SetPageOptions(thePB, false, false);
		if (rc != CQ_SUCCESS) goto onErr;

		// color the user specified objects
		rc = ColorObjects(thePB, bDoubleSided);
		if (rc != CQ_SUCCESS) goto onErr;
	}

	GotoPage(thePB, rememberPage); // restore user's original page
	SetPageOptions(thePB, bDoubleSided, bFacingPages); // restore page setup

onErr:
	if (gpCmdQry)
		gpIntfMgr->ReleasePMInterface((LPVOID *)gpCmdQry);

	return rc;
}

/*
 *--- DoLoad ------------------------------------------------------------------
 *  					    
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoLoad(PMMessage* pMsg)
{
	PMXErr 	result = SUCCESS;
	PMBool 	doRectangles,
			doOvals,
			doLines;
	short	radioChoice;
	char 	rangeString[MAXEDITSTRING];
	char 	colorString[MAXEDITSTRING];

	gpIntfMgr = pMsg->pInterfaceMgr;

	if (!gpIntfMgr->AcquirePMInterface(PMIID_CMDQRY, (LPVOID *)&gpCmdQry))
		gpCmdQry->Retrieve (&thePB);
	else
		return FAILURE;
	
	GetDefaults(thePB, &doRectangles, &doOvals, &doLines, &radioChoice, rangeString, colorString);
	SetData(thePB, doRectangles, doOvals, doLines, radioChoice, rangeString, colorString);

	if (gpCmdQry)
		gpIntfMgr->ReleasePMInterface((LPVOID *)gpCmdQry);

	return result;
}

/*
 *--- DoEvent -----------------------------------------------------------------
 *  
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoEvent(PMMessage* pMsg)
{
	PMXErr 	result = SUCCESS;

	gpIntfMgr = pMsg->pInterfaceMgr;

	return result;
}

/*
 *--- DoSysEvent --------------------------------------------------------------
 *  
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoSysEvent(PMMessage* pMsg)
{
	PMXErr 	result = SUCCESS;

	gpIntfMgr = pMsg->pInterfaceMgr;

	return result;
}

/*
 *--- DoUnload ----------------------------------------------------------------
 *  
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoUnload(PMMessage* pMsg)
{
	PMXErr 	result = SUCCESS;

	gpIntfMgr = pMsg->pInterfaceMgr;
 
	return result;
}

/*
 *--- DoShutdown --------------------------------------------------------------
 *  
 *-----------------------------------------------------------------------------
 */ 
PMXErr DoShutdown(PMMessage* pMsg)
{
	PMXErr 	result = SUCCESS;

	gpIntfMgr = pMsg->pInterfaceMgr;

	return result;
}

PMXErr DoCleanup(PMMessage* pMsg)
{
	PMXErr 	result = SUCCESS;

	gpIntfMgr = pMsg->pInterfaceMgr;

	return result;
}

/*
 *--- SetData -----------------------------------------------------------
 * Stores the dialog options into the Private data portion of thePB,
 * so that the same dialog options can be used when the plug-in is
 * run again.
 *-----------------------------------------------------------------------
 */
void SetData(sPMParamBlockPtr thePB, PMBool doRectangles, PMBool doOvals, PMBool doLines,
		short radioChoice, char *rangeString, char *colorString)
{
	sColorDataHdl	myDataH;
	
	myDataH = (sColorDataHdl) thePB->pluginData;
	if (!myDataH)
	{
		// Doing first Invocation Initialization, so allocate ConnectionData
		myDataH = (sColorDataHdl) MMAlloc(sizeof(sColorerData));
		if (myDataH == NULL) return;
		thePB->pluginData = (void *) myDataH;
	}
	MMLock((PMHandle)myDataH);	

	// Save the current button states into the ConnectionData structure
	(**myDataH).doRectangles = doRectangles;
	(**myDataH).doOvals = doOvals;
	(**myDataH).doLines = doLines;
	(**myDataH).radioChoice = radioChoice;
	// Save the text string into the ConnectionData structure
	strcpy((**myDataH).rangeText, rangeString);
	strcpy((**myDataH).colorText, colorString);
	MMUnlock((PMHandle)myDataH);	
}

/*
 *--- GetData -----------------------------------------------------------
 * Load the stored dialog options from the Private data portion of
 * thePB into the variables representing the dialog options,
 * or return false if there isn't any plug-in Private data yet
 * because this is the first invocation of this plug-in
 *-----------------------------------------------------------------------
 */
PMBool GetData(sPMParamBlockPtr thePB, PMBool *doRectangles, PMBool *doOvals, PMBool *doLines,
		short *radioChoice, char *rangeString, char *colorString)
{
	sColorDataHdl	myDataH = (sColorDataHdl) thePB->pluginData;
	
	if (myDataH == NULL) return false;
	
	MMLock((PMHandle) myDataH);
	// Load the current button states from the ConnectionData structure
	*doRectangles = (**myDataH).doRectangles;
	*doOvals = (**myDataH).doOvals;
	*doLines = (**myDataH).doLines;
	*radioChoice = (**myDataH).radioChoice;
	// Load the text string from the ConnectionData structure
	strcpy(rangeString, (**myDataH).rangeText);
	strcpy(colorString, (**myDataH).colorText);

	MMUnlock((PMHandle) myDataH);

	return true;
}

/*
 *--- GetDefaults -------------------------------------------------------
 * Initializes the variables representing dialog options
 *-----------------------------------------------------------------------
 */
PMBool GetDefaults(sPMParamBlockPtr thePB, PMBool *doRectangles, PMBool *doOvals,
		PMBool *doLines, short *radioChoice, char *rangeString, char *colorString)
{
	// Set the toggle buttons according to the default values
	*doRectangles = true;
	*doOvals = true;
	*doLines = true;
	*radioChoice=allButton;
	// set the rangeString to empty
	rangeString[0]='\0';
	if (!GetDefaultColor(thePB, colorString))
		return false;
	return true;
}


/*
 *--- ParsePages --------------------------------------------------------
 * Converts the text in variable rangeString into integers firstPage
 * and lastPage, or returns false if this cannot be done properly
 *
 * Note that sscanf cannot be used since this is a DLL.
 * Also, This routine allows for cases such as "4", "-4", "4-",
 * and "4-5", and it checks for errors.
 *-----------------------------------------------------------------------
 */
PMBool ParsePages(sPMParamBlockPtr thePB, short *first, short *last, char *rangeString)
{
	short firstPage, lastPage;
	char tempString[MAXEDITSTRING];
	short i, lastValidPage, dashPosition, firstWordPosition;
	strcpy(tempString, rangeString);

	dashPosition = -1;
	i = 0;
	while (tempString[i] != '\0')
	{
		// find dash position, and convert to space
		if (tempString[i] == '-')
		{
			if (dashPosition != -1)
				return false; // only one dash allowed!
			else
			{
				dashPosition = i;
				tempString[i] = ' ';
			}
		} // if a dash was found
		// rejects any non-legal character
		if (tempString[i] != ' ' && (tempString[i] < '0' || tempString[i] > '9') )
			return false;
		i++;
	}
	i = 0;
	// proceed to beginning of first number
	while (tempString[i] == ' ')
		i++;

	firstWordPosition = i; // remember where the first word started
	if (tempString[i] == '\0')
		return false; // no numbers, only spaces

	// proceed to end of first number
	firstPage = 0;
	while (tempString[i] >= '0' && tempString[i] <= '9')
	{
		firstPage = firstPage*10 + (short)(tempString[i]-'0');
		i++;
	}
	// proceed to beginning of second number
	while (tempString[i] == ' ')
		i++;

	if (tempString[i] == '\0') // only one number given
	{
		if (dashPosition == -1) // no dash given. example "4"
			lastPage = firstPage;
		else if (dashPosition < firstWordPosition) // example "-4"
		{
			lastPage = firstPage;
			firstPage = 1;
		}
		else
			lastPage = DoShortQuery(thePB, pm_getpages); // example "4-"
	}
	else // at least two numbers were given. example "4-5"
	{
		// proceed to end of second number
		lastPage = 0;
		while (tempString[i] >= '0' && tempString[i] <= '9')
		{
			lastPage = lastPage * 10 + (short)(tempString[i] - '0');
			i++;
		}
		// make sure there were not more than two numbers given
		while (tempString[i] == ' ')
			i++;
		if (tempString[i] != '\0') // a third number was given
			return false;
	} // else, at least two numbers given
	
	// Check the two numbers for errors
	lastValidPage = DoShortQuery(thePB, pm_getpages);

	if (firstPage < 1 || firstPage > lastValidPage)
		return false;

	if (lastPage < 1 || lastPage > lastValidPage)
		return false;

	if (firstPage > lastPage)
		return false;

	*first = firstPage;
	*last  = lastPage;

	return true; // the number or numbers are legal
}


/*
 *--- GetDefaultColor ---------------------------------------------------
 * Queries PageMaker about the current color.
 *-----------------------------------------------------------------------
 */
PMBool GetDefaultColor(sPMParamBlockPtr thePB, char *defaultColor)
{
	PMHandle theHandle;
	PMBool ok = false;

	if (!PBBinQuery(thePB, pm_getcolor, kXRSHandle, (void *) NULL, (unsigned long) NULL))
	{
		if (theHandle = (PMHandle) thePB->replyData)
		{
			char * theData;
			if (theData = (char *)MMLock(theHandle))
			{
				// an example of parameter unpacking
				theData += LPGetString(defaultColor, theData, MAXEDITSTRING-1);
				ok = true;
				MMUnlock(theHandle);
			}
			MMFree(theHandle);
		}
	}
	return ok;
}

/*
 *--- ColorObjects ------------------------------------------------------
 * Uses the variables doRectangles, doOvals, doLines,
 * firstPage, lastPage, and colorString to color a subset of all the
 * objects in a PageMaker document
 *-----------------------------------------------------------------------
 */
PMBool ColorObjects(sPMParamBlockPtr thePB, PMBool bDoubleSided)
{
	PMHandle hColor;
	short i; //, j, k, numObjects;
//	long skip;
//	short nDrawingNumber, cTypeOfObject;
	PMBool doRectangles, doOvals, doLines;	// user's choice of objects
	short firstPage, lastPage;						// the first and last page to be colored
	char colorString[MAXEDITSTRING];
	short size;
	PMBool ok = false;

	// Fill in the user's choice variables with the plug-in Data values.
	ConvertParameters(thePB, bDoubleSided, &doRectangles, &doOvals,
			&doLines, &firstPage, &lastPage, colorString);
	
	size = strlen(colorString) + 1;
	size += size & 0x0001;
	size += 2;		

	CIObjectAccess		*pObjAcc = NULL;
	PMObjAttr 			objAttr;
	PMOBJ_REC			objRec;
	PMXErr				result;
	DWORD				objID;

	//acquire Object Access Interface
	if ( gpIntfMgr ) {
	 	gpIntfMgr->AcquirePMInterface(PMIID_OBJACC, (LPVOID *)&pObjAcc);
		if ( !pObjAcc )
			return false;
	}

	// first deselect everything
	//PBBinCommand(thePB, pm_deselect, kXRSNull, NULL, NULL);

	for (i = firstPage; i <= lastPage; i++)
	{
	 	result = pObjAcc->GetFirstObject(kIncludeInlines|kIncludeGroupObjects,
	 									&objRec,i);
		if ( result )
		   break; //exit the loop

		do {
			//Get object's basic information
			pObjAcc->GetObjAttr(&objRec, &objAttr);

			if ((doRectangles && objAttr.type == 4) //Pagemaker box
				|| (doOvals && objAttr.type == 5) //Pagemaker oval
				|| (doLines && objAttr.type == 3)) //Pagemaker line
			{
				pObjAcc->GetObjID(&objRec, &objID);
				//Select the Object
				PBBinCommandByLongValue(thePB, pm_selectid, (unsigned long)objID);

				if ((hColor = MMAlloc(size)) != NULL)
				{
					char * lpColor;
					char * lpColor0;
					if ((lpColor0 = (char *) MMLock(hColor))!=NULL)
					{
						lpColor = lpColor0;
						// how to pack parameters
						lpColor += LPPutString(lpColor, colorString);
						lpColor += LPPutShort(lpColor, 1000);
						PBBinCommand(thePB, pm_color, kXRSPointer, lpColor0, lpColor-lpColor0);
						MMUnlock(hColor);
					}
					MMFree(hColor);
				}
			}
		} while (!pObjAcc->GetNextObject(&objRec));
	} // end page loop

	//release Object Access Interface
	if ( pObjAcc )
		gpIntfMgr->ReleasePMInterface(pObjAcc);
/*
	// Loop through each chosen page
	for(i = firstPage; i <= lastPage; i++)
	{
		GotoPage(thePB, i);
		// Get the objects on page i
		if (!PBBinQuery(thePB, pm_getobjectlist, kXRSHandle, NULL, NULL))
		{
			if (theHandle = thePB->replyData)
			{
				char * theData;
				if (theData = (char *)MMLock(theHandle))
				{
					// extract the number of objects on this page from theData
					theData += LPGetShort(&numObjects, theData);
					// for each object, check if it matches one of the
					// object types chosen by the user.
					// if so, make it the color chosen by the user.
					for(j = 1; j <= numObjects; j++)
					{
						PMHandle hColor; // for plug-in command pm_color
						// An example of parameter unpacking
						theData += LPGetShort(&nDrawingNumber, theData);
						theData += LPGetShort(&cTypeOfObject, theData);
						
						for(k = 0; k < 4; k++) // skip position fields
							theData += LPGetLong(&skip, theData);
							
						if ((doRectangles && cTypeOfObject == 4) //Pagemaker box
							|| (doOvals && cTypeOfObject == 5) //Pagemaker oval
							|| (doLines && cTypeOfObject == 3)) //Pagemaker line
						{
							// Select the chosen object
							// NOTE: The following structure block demonstrates
							// an alternative form of parameter packing
							{
								struct SelectType
								{
									short nModel;
									long x1OrNum;
									long y1;
								} selectData;
								selectData.nModel = 1; // select by drawing order
								selectData.x1OrNum = nDrawingNumber;
								PBBinCommand(thePB, pm_select, kXRSPointer, &selectData, sizeof(struct SelectType));
							}

							// Assign the selected object the chosen color
							if ((hColor = MMAlloc(size)) != NULL)
							{
								char * lpColor;
								char * lpColor0;
								if ((lpColor0 = (char *) MMLock(hColor))!=NULL)
								{
									lpColor = lpColor0;
									// how to pack parameters
									lpColor += LPPutString(lpColor, colorString);
									lpColor += LPPutShort(lpColor, 1000);
									PBBinCommand(thePB, pm_color, kXRSPointer, lpColor0, lpColor-lpColor0);
									MMUnlock(hColor);
								}
								MMFree(hColor);
							}
								
						} // if this object should be acted upon
					}
					ok = true;
					MMUnlock(theHandle);
				}
				MMFree(theHandle);
			}
		}
	}
*/
	return ok;
}

/*
 *--- ConvertParameters -------------------------------------------------
 * Retrieves the plug-in data parameters and converts rangeString
 * to firstPage and lastPage.
 *-----------------------------------------------------------------------
 */
void ConvertParameters(sPMParamBlockPtr thePB, PMBool bDoubleSided, PMBool * doRectangles,
		PMBool * doOvals, PMBool * doLines,
		short * firstPage, short * lastPage, char * colorString)
{
	char rangeString[MAXEDITSTRING];
	short radioChoice;
	
	GetData(thePB, doRectangles, doOvals, doLines, &radioChoice, rangeString, colorString);
	if (radioChoice == allButton)
	{
		*firstPage = 1;
		*lastPage = DoShortQuery(thePB, pm_getpages); // last page
	}
	if (radioChoice == currentButton)
	{
		*lastPage = DoShortQuery(thePB, pm_getpagenumber); // current page
		*firstPage = *lastPage;
		if (*firstPage > 1 && bDoubleSided)
			(*firstPage)--;
	}
	if (radioChoice == rangesButton)
	{
		// NOTE: the validity of rangeString was already verified in the dialog procedure.
		ParsePages(thePB, firstPage, lastPage, rangeString);
	}
}


// end of Colorer.c
