/*
 *--- ColorerUtils.c ----------------------------------------------------
 * Copyright (c) 1995, Adobe Systems, Inc.  All rights reserved.
 *
 * These are handy utility functions used by Colorer.  You may find
 * them useful in your plug-ins as well.
 *-----------------------------------------------------------------------
 */

#include "PMPlugin.h"
#include "CUtils.h"

/*
 *--- GotoPage ----------------------------------------------------------
 * Sends a command to set the current page to pageNumber
 *-----------------------------------------------------------------------
 */
PMErr GotoPage(sPMParamBlockPtr thePB, short pageNumber)
{
	return PBBinCommandByShortValue(thePB, pm_page, pageNumber);
}

/*
 *--- GetPageNumber -----------------------------------------------------
 * Return the current page number.
 *-----------------------------------------------------------------------
 */

short GetPageNumber(sPMParamBlockPtr thePB)
{
	return DoShortQuery(thePB, pm_getpagenumber);
}

/*
 *--- SetPageOptions ----------------------------------------------------
 * Sends a command to PageMaker to set the double-sided and
 * facing-pages states
 *-----------------------------------------------------------------------
 */
PMErr SetPageOptions(sPMParamBlockPtr thePB, PMBool bDoubleSided, PMBool bFacingPages)
{
	PMHandle theHandle;
	PMErr rc = CQ_FAILURE;

	if (theHandle = MMAlloc(sizeof(short)*2))
	{
		char * theData;
		if (theData = (char *)MMLock(theHandle))
		{
			// an example of parameter packing
			theData += LPPutShort(theData, bDoubleSided ? 1 : 0);
			theData += LPPutShort(theData, bFacingPages ? 1 : 0);
			MMUnlock(theHandle);
		}
		rc = PBBinCommand(thePB, pm_pageoptions, kXRSHandle, theHandle, sizeof(short)*2);
		MMFree(theHandle);
	}
	return rc;
}

/*
 *--- GetPageOptions ----------------------------------------------------
 * Queries PageMaker about whether the pages are double sided
 * and/or facing pages
 *-----------------------------------------------------------------------
 */
PMErr GetPageOptions(sPMParamBlockPtr thePB, PMBool *bDoubleSided, PMBool *bFacingPages)
{
	PMHandle theHandle;
	PMErr rc;

	rc = PBBinQuery(thePB, pm_getpageoptions, kXRSHandle, NULL, NULL);
	if (rc != CQ_SUCCESS) return rc;

	if (theHandle = (PMHandle)thePB->replyData)
	{
		char * theData = (char *)MMLock(theHandle);
		short temp;
		theData += LPGetShort(&temp, theData);
		*bDoubleSided = temp;
		theData += LPGetShort(&temp, theData);
		*bFacingPages = temp;
		MMUnlock(theHandle);
		MMFree(theHandle);
	}
	else
		return CQ_FAILURE;
	return rc;
}

/*
 *--- DoShortQuery ------------------------------------------------------
 * Issues the (single short return) PageMaker query indicated
 * by the binary number, "operationCode", and returns the result
 *-----------------------------------------------------------------------
 */
short DoShortQuery(sPMParamBlockPtr thePB, short operationCode)
{
	PMHandle theHandle;
	short vShort;

	if (!PBBinQuery(thePB, (ePMQuery)operationCode, kXRSHandle, NULL, NULL))
	{
		if (theHandle = (PMHandle)thePB->replyData)
		{
			char * theData;
			if (theData = (char *) MMLock(theHandle))
			{
				theData += LPGetShort(&vShort, theData);
				MMUnlock(theHandle);
			} 
			MMFree(theHandle);
		}
	}
	return vShort;
}



