/*
 *--- ColorerUIWin.c --------------------------------------------------
 * PageMaker plug-in Example Dialog File
 *
 * ABSTRACT:
 * This example plug-in illustrates working with:
 *		Dialogs
 *		Commands and Queries
 *		PageMaker objects
 *		Parameter packing and unpacking
 *
 * This file contains the routines to support the Windows dialog box
 *---------------------------------------------------------------------
 */

#include <string.h>

#include "PMPlugin.h"
#include "colorer.h"
//#include "ColorerDialog.h" became:
//#include "ColorerUIWin.h"

PMBool  DisplayDialog(HWND hDlg, UINT wMsg, WPARAM wParam, LPARAM lParam);
PMBool  GetColorNames(sPMParamBlockPtr thePB, char *colorNames);


extern sPMParamBlockPtr gPB;
extern HANDLE hDllInstance; 		// Instance of this DLL
PMHandle theColors;

/*
 *--- DoDialog -------------------------------------------------------------
 * Creates a dialog box allowing the user to enter several parameters.
 *--------------------------------------------------------------------------
 */
short DoDialog(sPMParamBlockPtr thePB)
{
	void * lpprocDia;
	HWND hWnd;
	int doit;

	// Get hWnd of PageMaker, the dialog's parent to be
	hWnd=GetActiveWindow();
	gPB=thePB;
	doit = DialogBox(hDllInstance, "MYBOX", hWnd,(DLGPROC)DisplayDialog);
	
	return doit;
}

/*
 *--- DisplayDialog -----------------------------------------------------
 * The Windows call back procedure for all events occuring in the
 * dialog box created below in GetParameters
 *
 * Initialized the dialog box on the WM_INITDIALOG message.
 * Responds to various events on WM_COMMAND messages.
 *
 * If the user chooses OK, then the chosen parameters are stored in
 * the plug-in data block and true is returned.
 * Else, false is returned.
 *--------------------------------------------------------------------
 */
PMBool DisplayDialog(HWND hDlg, UINT wMsg, WPARAM wParam, LPARAM lParam)
{
	// user's choice of objects to act upon
	static PMBool rectanglesState,ovalsState,linesState;
	static short radioChoice;
	static char rangeString[MAXEDITSTRING];
	static short dummyFirst,dummyLast;
	static HWND hEdit,hCombo;
	static char * colorNames;
	static char tempColorString[MAXEDITSTRING];
	static char colorString[MAXEDITSTRING];
	static short numColors,num;
	static PMErr rc;

	switch (wMsg)
	{
	case WM_INITDIALOG:
		// Get handles to edit boxes
		hEdit = GetDlgItem(hDlg,rangesEdit);
		hCombo = GetDlgItem(hDlg,colorEdit);
		// Get initial button states and edit box values
		if (GetData(gPB,&rectanglesState,&ovalsState,&linesState,&radioChoice,
				rangeString,colorString)==false)
			// first call to the plug-in
			GetDefaults(gPB,&rectanglesState,&ovalsState,&linesState,
					&radioChoice,rangeString,colorString);
		// Init dialog box values according to the current button states
		CheckRadioButton(hDlg,allButton,rangesButton,radioChoice);
		CheckDlgButton(hDlg,rectanglesButton,rectanglesState);
		CheckDlgButton(hDlg,ovalsButton,ovalsState);
		CheckDlgButton(hDlg,linesButton,linesState);
		// Init page range edit box
		SetDlgItemText(hDlg,rangesEdit,rangeString);
		// Init color combo box
		SendMessage(hCombo, CB_RESETCONTENT,0,0L);
		rc=PBBinQuery(gPB,pm_getcolornames,kXRSHandle,NULL,NULL);
		if (rc != CQ_SUCCESS) 
		{// I need to add a warning here, that there was failure
			EndDialog(hDlg, false); //Don't do anything
			return false;
			break;
		}
		if(theColors = gPB->replyData)
		{
			colorNames = (char *)MMLock(theColors);   
			if(colorNames==NULL)
			{
				MMFree(theColors);
				EndDialog(hDlg, false); //Don't do anything
				return false;
				break;
			}
		}	
		colorNames+= LPGetShort(&numColors,colorNames);
		for(num=0;num<numColors;num++)
		{
			colorNames+= LPGetString(tempColorString,colorNames,MAXEDITSTRING-1);
			SendMessage(hCombo, CB_ADDSTRING,0,(DWORD)(char *)tempColorString);
		}
		MMUnlock(theColors);
		MMFree(theColors);
		SendMessage(hCombo, CB_SELECTSTRING,0,(DWORD)(char *)colorString);
		return false; // Windows should also handle the event
		break;

	case WM_COMMAND:
		switch (wParam) // wParam indicates which button or box got the event
		{
		case okButton:
			// copy range edit box to variable rangeString
			GetDlgItemText(hDlg,rangesEdit,rangeString,MAXEDITSTRING-1);

			if (radioChoice == rangesButton &&
					ParsePages(gPB,&dummyFirst, &dummyLast, rangeString) == false)
			{
				// Bad range. highlight for easy retry, dont quit
				SetFocus(hEdit);
				SendDlgItemMessage(hDlg,rangesEdit,EM_SETSEL,0,MAKELONG(0,-1));
			}
			else // the dialog box parameters are valid
			{
				// read the remaining dialog box values
				rectanglesState = IsDlgButtonChecked(hDlg,rectanglesButton);
				ovalsState      = IsDlgButtonChecked(hDlg,ovalsButton);
				linesState      = IsDlgButtonChecked(hDlg,linesButton);
				GetDlgItemText(hDlg,colorEdit,colorString,MAXEDITSTRING-1);
				// save and use these same values next time
				SetData(gPB, rectanglesState,ovalsState,linesState,
						radioChoice,rangeString,colorString);
				EndDialog(hDlg, true); // DO IT!
			}
			break;

		case cancelButton:
			EndDialog(hDlg, false); // Don't do it.
			break;

		case allButton:
			radioChoice = 9;
			break;
		case currentButton:
			radioChoice = 10;
			break;
		case rangesButton:
			radioChoice = 11; // keep track of selected radio button.
			break;

		default:
			return false; // Windows should handle the event
			break;
		}
		break;

	default:
		return false; // Windows should handle the event
		break;
	}
	return true; // Windows need not handle the event
}

/**[r*********************************************************************
 * GetColorNames
 *
 * DESCRIPTION:
 *              Queries PageMaker for the current color names and stores them
 * in the string pTheColors.
 * NOTE:
 * The handle for this data is NOT released here, but in FreeColorNames.
 **r]*********************************************************************/
PMBool GetColorNames(sPMParamBlockPtr thePB,char *colorNames)
{
	PMErr rc;
	rc=PBBinQuery(thePB,pm_getcolornames,kXRSHandle,NULL,NULL);
	if (rc != CQ_SUCCESS) return rc;

	if(theColors = thePB->replyData)
		{
		if(colorNames = (char *)MMLock(theColors))   
			return(TRUE);
		else
			MMFree(theColors);
		}
	return(FALSE);
} /* GetColorNames */

// end of ColorerUIWin.c
