/*
 *--------------------------------------------------------------------
 * Copyright (c) 1996, Adobe Systems Inc. All rights reserved.
 *
 * The Windows dialog for the Colorer Plug-in
 *--------------------------------------------------------------------
 */

#include <string.h>

#include "ColorerDialog.h"

#include "PStringListQuery.h"

#ifdef WINDOWS
	extern PMHandle	hDllInstance;
#endif //WINDOWS

	UColorerData * ColorerDialog::colorData = 0;
	ColorerPlugin * ColorerDialog::itsColorer = 0;


/*
 *-ColorerDialog------------------------------------------------------
 * Creates the dialog box for the Colorer Plug-in. If the user chooses 
 * OK from the dialog, the parameters are stored in the plug-in's data
 * block.
 *--------------------------------------------------------------------
 */
ColorerDialog::ColorerDialog(ColorerPlugin &theColorer)

{
	itsColorer=&theColorer;
	HWND hWnd=GetActiveWindow();
	doit = DialogBox(hDllInstance, "MYBOX", hWnd, (DLGPROC)DisplayDialog);
	if (doit != 0) 
	theColorer.ColorObjects();
}

int ColorerDialog::DisplayDialog(HWND hDlg, UINT wMsg, WPARAM wParam, LPARAM lParam)
 {
	static HWND hEdit, hCombo;
	colorData = (UColorerData *) itsColorer->GetPluginData();

	switch (wMsg)
	{
	case WM_INITDIALOG:
		hEdit = GetDlgItem(hDlg,rangesEdit);
		hCombo = GetDlgItem(hDlg,colorEdit);
		CheckRadioButton(hDlg,allButton,rangesButton,colorData->radioChoice);
		CheckDlgButton(hDlg,rectanglesButton,colorData->doRectangles);
		CheckDlgButton(hDlg,ovalsButton,colorData->doOvals);
		CheckDlgButton(hDlg,linesButton,colorData->doLines);
		SetDlgItemText(hDlg,rangesEdit,colorData->rangeText);
		SendMessage(hCombo, CB_RESETCONTENT, 0, 0L);
		
		InitColorPopup(hCombo);
		return false;
		break;

	case WM_COMMAND:
		switch (wParam)
		{
		case okButton:
			GetDlgItemText(hDlg,rangesEdit,colorData->rangeText,MAXEDITSTRING-1);

			if 	(colorData->radioChoice == rangesButton &&
				itsColorer->ParsePages((UColorerData&) colorData) == false)
			{
				SetFocus(hEdit);
				SendDlgItemMessage(hDlg,rangesEdit,EM_SETSEL, 0, MAKELONG(0,-1));
			}
			else
			{
				colorData->doRectangles = IsDlgButtonChecked(hDlg,rectanglesButton);
				colorData->doOvals = IsDlgButtonChecked(hDlg,ovalsButton);
				colorData->doLines = IsDlgButtonChecked(hDlg,linesButton);
				GetDlgItemText(hDlg,colorEdit,colorData->colorText,MAXEDITSTRING-1);
				itsColorer->SetPluginData(colorData);
				EndDialog(hDlg,true);
			}
			break;
  
		case cancelButton:
			EndDialog(hDlg,false);
			break;

		case allButton:
			colorData->radioChoice=choiceAllPages;
			break;
		
		case currentButton:
			colorData->radioChoice=choiceCurrentPage;
			break;

		case rangesButton:
			colorData->radioChoice=choicePageRange;
			break;

		default:
			return false;
			break;
		}
		break;

	default:
		return false;
		break;
	}
	return true;
}

void ColorerDialog::InitColorPopup(HWND& hCombo)
{
	PGetColorNames colorNames;
	char tempColorString[MAXEDITSTRING],
		 tempColorChoice[MAXEDITSTRING];

	colorNames.Reset();
	for(int i = 0; i<colorNames.Count(); i++)
	{
		strncpy(tempColorString, colorNames, MAXEDITSTRING);
		SendMessage(hCombo, CB_ADDSTRING, 0, (DWORD)(char *)tempColorString);
		colorNames++;
	}

	strncpy(tempColorChoice, colorData->colorText,MAXEDITSTRING);
	SendMessage(hCombo, CB_SELECTSTRING, 0, (DWORD)(char *)tempColorChoice);
}



