/***[f*****************************************************************
 *	CImsave.h	-- Save image Interface. 
 *
 *	Copyright 1996 (c) Adobe Systems, Inc. All Rights Reserved
 *
 *	Public version
 *
 * $Revision:   1.10  $
 *
 *
 *
 ***f]*****************************************************************/

#ifndef __CIMSAVE_H
#define __CIMSAVE_H

#include "PMKeywords.h"

// CISaveImage interace export an image or a vector graphic (PICT, Metafile, and EPS).
// to an image file format. If EPS file, its preview is used.
// The supported file formats are: TIFF, JPEG, GIF89, and DCS.

#ifdef __cplusplus
class CISaveImage : public CIInterface
{
public:
	virtual	~CISaveImage() {};
	
	// Set up to export graphic. This method assume that only one graphic 
	// object is already selected.
	virtual PMXErr Setup() = 0;

	// Use this when ready to export the graphic. If this is called without setting
	// any options, then default values are used.
	virtual PMXErr SaveIt() = 0;

	// Use this when PMOBJ_REC is available. In this case, graphic object
	// does not need to be preselected.
	virtual PMXErr Setup( PMOBJ_REC	*pPMObjRec ) = 0;

	// This must be called when finished.
	virtual void Finished( PMBool bUpdate) = 0;
	
	// The following methods set various options. If possible, setting may be verified
	// and adjusted to the more appropriate value. This new value will be returned.
	// If a value is not applicable and is ignored, a "-1" is returned.
	// One Setup method must be already called before any settings can take effect.

	// Common options
	virtual void SetIgnoreErrorAlertFlag( PMBool bYes ) = 0;
	virtual void SetFileFormat( short *pFileformat, char *pFilename, unsigned short filenameSize ) = 0;
	virtual void SetSaveSep( PMBool *pValue ) = 0;
	virtual void SetEmbedProfile( PMBool *pValue ) = 0;
	virtual void SetSaveStandardDisplay( PMBool *pValue ) = 0;
	virtual void SetSaveCrop( PMBool *pValue ) = 0;
	virtual void SetRelink( PMBool *pValue ) = 0;
	
	// TIFF options
	virtual void SetTiffCompression( short *pValue ) = 0;
	virtual void SetTiffPreview( short *pValue ) = 0;
	virtual void SetTiffFormat( short *pValue ) = 0;
	virtual void SetTiff6Compliance( PMBool *pValue ) = 0;
	virtual void SetTiffColorDepth( short *pValue ) = 0;
	
	// JPEG options
	virtual void SetJpegQuality( short *pValue ) = 0;
	virtual void SetJpegResolution( short *pValue ) = 0;
	virtual void SetJpegCmykToRgbConversion( PMBool *pValue ) = 0;
	
	// GIF options
	virtual void SetGifTransparency( short *pValue ) = 0;
	virtual void SetGifInterlaced( PMBool *pValue ) = 0;
	virtual void SetGifPalette( short *pValue ) = 0;
	virtual void SetGifColorDepth( short *pValue ) = 0;
	virtual void SetGifCaption( char *pCaption, unsigned short size ) = 0;
	virtual void SetGifResolution( short *pValue ) = 0;
	
	// DCS options
	virtual void SetDcsMultiFiles( PMBool *pValue ) = 0;
	virtual void SetDcsAscii( PMBool *pValue ) = 0;
	virtual void SetDcsScreenPreview( short *pValue ) = 0;
	virtual void SetDcsCompPreview( short *pValue ) = 0;
};
  
#endif	// __cplusplus
#endif	// __CIMSAVE_H
