/************************************************************************************
	hcmtypes.h
		This file contains types and definitions for usage with the 
		HyperContentManager.
	
	Copyright:	 1996 by Adobe Systems, Inc., all rights reserved.
************************************************************************************/



#if !defined( HCMTYPES_H )
	#define HCMTYPES_H
	


	/************************************************************************************
									Dependent headers
	************************************************************************************/
		//
		// include the public definitions of things.
		//
	#if !defined( HCMDEFS_H )
		#include "hcmdefs.h"
	#endif /* HCMDEFS_H */
	
	
	
	/************************************************************************************
									Type definitions
	************************************************************************************/
		//
		// want to be able to use these on all platforms
		//
	typedef char				INT8;
	typedef short				INT16;
	typedef long				INT32;
	typedef int					INT;
	typedef unsigned char		UINT8;
	typedef unsigned short		UINT16;
	typedef unsigned long		UINT32;
	//typedef unsigned int		UINT;		// already defined elsewhere
	


	/************************************************************************************
									Public Hcm-types
	************************************************************************************/
	//($pubtypes)
        //
        // HcmObjectId is the unique number the HyperContent Manager uses to
        //  manage these objects.  This is a number between 1 ( kINVAL_HCID 
        //  is 0 ) and MAXINT32 used 	for uniquely identifying objects.  It's 
        //  used as glue for tying pdf or html or other information to the 
        //  anchor or hyperlink.
        //
/*
    enum HcmObjectIdEnum 
    {
        kHcmInvalidObjectId =  0
    }; // HcmObjectIdEnum
    typedef enum HcmObjectIdEnum  HcmObjectIdEnum;
    typedef HcmObjectIdEnum  HcmObjectId;
*/
    
    #define kHcmInvalidObjectId 0
    typedef UINT32	HcmObjectId;

        //
        // PageMaker unique data -- This defines exactly where this HyperContent lives
        //  in the publication.
        //
    struct HcmPmUniqueRec
    {
    	UINT32  m_SegmentType;  // segmentPtr->type or CIX_PAGEREF
        UINT32  m_OuterRid;  // story RID for CIX_PAGEREF, segment RID for others.
        UINT32  m_InnerRid;  // INVAL_RID
    }; // HcmPmUniqueRec
    typedef struct HcmPmUniqueRec HcmPmUniqueRec;

        //
        // this type defines the date/time format that is public for this code.
        //
    typedef UINT32        HcmDate;

        //
        // type containing the version number of the Hcm
        //
	typedef UINT32        HcmVersionNumber;

        //
        // type of HcmObject
        //
    enum HcmObjectTypeEnum 
    {
    	kHcmInvalidObjectDesc =  kHcmSpecialType, 
        kHcmStorageOnly =  'STOR',
        kHcmAnchorPubInternal =  'PUBI',
        kHcmAnchorPubExternal =  'PUBE',
        kHcmAnchorUrlExternal =  'URLE',
        kHcmHyperlinkInternal =  'HYPL'
    }; // HcmObjectTypeEnum
    typedef enum HcmObjectTypeEnum HcmObjectTypeEnum;

        //
        // who the caller is -- these pre-assigned ids should not be used as client
        //	identifiers by external unknown plug-in developers.
        //
    enum HcmCallerIdEnum 
    {
        kHcmInvalidCallerId =  kHcmSpecialType,
        	//
        	// internal clients
        	//
        kHyperContentManager =  'HCM ',
        kHcmContentBoss =  'CBOS',
        kHcmContentHandler =  'CHDR',
        kHcmContext =  'CNTX',
        kHcmObject =  'OBJ ',
        kHcmObjectList =  'OLST',
        kHcmPanelBoss =  'PBOS',
        kHcmRelationshipList =  'RLST',
        kHcmStorageBoss =  'SBOS',
        kHcmHyperlinksPalette =  'USER', 
        	//
        	// PageMaker clients
        	//
        kHcmPmTextEditor =  'PMTX',
        kHcmPmSegmentEditor =  'PMSG', 
        	//
        	// external known clients
        	//
        kHcmHtmlExport =  'HTME',
        kHcmHtmlImport =  'HTMI',
        kHcmCreatePdf =  'PDFE',
        kHcmHypertextLinking =  'HYPR', 
        kHcmMediaStore = 'MSTO' 
    }; // HcmCallerIdEnum
    typedef enum HcmCallerIdEnum HcmCallerIdEnum;

        //
        // what the name on the palette will be
        //
    struct HcmDisplayNameRec 
    {
        char  m_DisplayName[ kHcmMaxDisplayNameWidth ];
    }; // HcmDisplayNameRec
    typedef struct HcmDisplayNameRec HcmDisplayNameRec;

        //
        // describe what this thing is pointing to
        //
    union HcmPointToUnionRec
    {
        HcmObjectId  m_ObjectId;
        HcmPmUniqueRec  m_PageMakerRec;
        HcmDisplayNameRec  m_DisplayRec;
    }; // HcmPointToUnionRec
    typedef union HcmPointToUnionRec HcmPointToUnionRec;
    enum HcmPointToDescEnum
    {
        kHcmSizeReservePointTo =  kHcmSpecialType, 
        kHcmInvalidPointToRec =  0,
        kHcmObjectId =  1,
        kHcmPmUniqueRec =  2,
        kHcmDisplayName =  3
    }; // HcmPointToDescEnum
    typedef enum HcmPointToDescEnum HcmPointToDescEnum;
    struct HcmPointToRec 
    {
        HcmPointToDescEnum  m_PointToDesc;
        HcmPointToUnionRec  m_PointToUnion;
    }; // HcmPointToRec
    typedef struct HcmPointToRec HcmPointToRec;

        //
        // describe what it is and hand over what you want to store
        //
    struct HcmItemPrivateStoreRec 
    {
        char *  m_StoreBuffer;
        UINT32  m_SizeOfBuffer;
    }; // HcmItemPrivateStoreRec
    typedef struct HcmItemPrivateStoreRec HcmItemPrivateStoreRec;

        //
        // describe what we're creating
        //
    struct HcmObjectCreateDescRec
    {
        HcmObjectTypeEnum  m_KindOfObject;
        HcmPmUniqueRec  m_PageMakerRec;
        HcmDisplayNameRec  m_DisplayRec;
        HcmPointToRec  m_PointToRec;
        HcmItemPrivateStoreRec  m_PrivateStore;
    }; // HcmObjectCreateDescRec
    typedef struct HcmObjectCreateDescRec HcmObjectCreateDescRec;

        //
        // describes the page location of this item.
        //
    enum HcmPmLocationEnum
    {
        kHcmSizeReservePmLocation =  kHcmSpecialType, 
        kHcmPasteboard =  ( -6 ),
        kHcmMasterPage =  ( -5 ),
        kHcmFirstPage =  ( -4 ),
        kHcmLastPage =  ( -3 ),
        kHcmNextPage =  ( -2 ),
        kHcmPrevPage =  ( -1 )
    }; // HcmPmLocationEnum
    typedef enum HcmPmLocationEnum HcmPmLocationEnum;

        //
        // verbs defining actions
        //
    enum HcmVerbEnum
    {
        kHcmObjectCreate =  'CREA',
        kHcmObjectDelete = 'DELE'
    }; // HcmVerbEnum
    typedef enum HcmVerbEnum HcmVerbEnum;

        //
        // structure defining verb action on what
        //
    struct HcmActionDescRec
    {
        HcmDate  m_When;
        HcmCallerIdEnum  m_Who;
        HcmVerbEnum  m_How;
        HcmObjectId  m_What;
    }; // HcmVerbEnum
    typedef struct HcmActionDescRec HcmActionDescRec;



#endif /* HCMTYPES_H */
