/**[f******************************************************************
 * aldtypes.h - Standard Aldus types and definitions.
 *
 * Copyright (C) 1988 Aldus Corporation.  All rights reserved.
 * Company confidential.
 *
 * ABSTRACT:
 *
 *              This is the "master" header file that should be included first
 *              by all Aldus projects.  It defines basic types and definitions
 *              which should be used across all projects.  It is also responsible
 *              for setting up the environment (via universe.h).
 *
 *              All other include files may assume that this file has already
 *              been included by the source file.
 *
 *
 *              What UNIVERSE.H should define:
 *
 *
 *                      The environment:        MACINTOSH || WINDOWS || OS2
 *
 *                      Debug Options:          [DEBUG && [MESSAGES]]
 *
 *                      The compiler:           MPW [&& MPW3_0] || LSC [&& LSC3]
 *
 *                      Header option:          [PRECOMPILED_HEADERS]  - won't include machdrs.h
 *                                                              This is mainly for Lightspeed users.  To get precompiled
 *                                                              headers for MPW, see machdrs.h.
 *
 *                      Override:                       override any  #ifndef wrapped define by defining it first
 *                                                              in universe.h.  Then this file won't define it.  Things
 *                                                              like LOCAL/PRIVATE etc. can be overridden this way.
 *
 *                      aldgeom.h                       If you don't want the standard coordinate types to
 *                                                              get defined when including aldtypes.h, then you
 *                                                              can #define NO_ALDGEOM (Dallas will want this,
 *                                                              Seattle probably won't).
 *
 *                      APPDEBUG_D                      Define this if you don't want aldtypes.h to attempt
 *                                                              to include a file (that your project must own) named
 *                                                              appdebug.h which contains your app specific debug macros.
 *
 *                      PASCAL_CALL                     If you want to let the compiler decide whether to use
 *                                                              C or Pascal calling conventions, then redefine PASCAL_CALL
 *                                                              in universe.h.  Something like this would work:
 *
 *                                                              #define PASCAL_CALL(type)       type
 *
 *                                                              If you do this and then compile -Gc under WINDOWS,
 *                                                              you must then explicitly declare functions that you
 *                                                              want to use C convertions as CDECL.
 *
 *                                                              In general, Pascal works better under WINDOWS, but
 *                                                              C conventions are better on the Mac.
 *
 *
 *              What your source file can do:
 *
 *                      NO_WORLD                                If you don't want to bring in the world
 *                                                                      (windows.h or machdrs.h) then your source file
 *                                                                      should #define NO_WORLD before including this file.
 *                                                                      You'll still get all the basic types & defs here.
 *              
 *
 *              BACKWARD COMPATIBILITY WITH EXISTING PROJECTS:
 *
 *              machine.h:
 *
 *              This file is still included, but is vastly different than before.  It
 *              now exists for backward compatibility with existing projects.  It only
 *              contains defines that existed from before.  One day, this file should go
 *              away completely.
 *
 *              Some definitions/typedefs in here I hope will eventually go away.
 *              However, in order to support existing code, they still live on and
 *              make this file more junky than it should be.  In particular, things
 *              like the mnemonics (NE, EQ, etc.) should get dumped.  Unfortunately,
 *              some still use these.
 *
 *              Multiple definitions for the same thing also appear (ABS, xabs, etc.)
 *              This is due to the different names used from project to project.  To
 *              support bringing everyone to one set of headers, we'll define all of
 *              them now to make integration as simple as possible.  The desired one
 *              to use will be marked and all new code should use that one in the
 *              future.
 *
 *
 **f]*****************************************************************/
#ifndef ALDTYPES_D
#define ALDTYPES_D


/*----------------------------------------------------------------------*/
/* Pull in universe.h.  This defines the environment.  Universe.h can   */
/* also be used to override many of the defines in this file.  By               */
/* defining them in universe.h first, we won't attempt to redefine them */
/* inside of this file.                                                                                                 */
/*----------------------------------------------------------------------*/
//#include "universe.h"


/*----------------------------------------------------------------------*/
/* The following is for including C include files from C++ sources.     */
/*      Under MPW, the linker sometimes requires C prototypes to be bracketed*/
/*      by extern 'extern "C" {...}'.  It is cool to bracket the #include       */
/*      statement (in the C++ file), thus not affecting the included file.      */
/*                                                                                                                                              */
/* For example, if one wanted to include the C include file cfile.h             */
/*      from a C++ source, then the following sequence might be included        */
/*      in the C++ file:                                                                                                        */
/*                                                                                                                                              */
/*              START_C_INCLUDE                                                                                                 */
/*              #include cfile.h                                                                                                */
/*              END_C_INCLUDE                                                                                                   */
/*----------------------------------------------------------------------*/
#ifdef __cplusplus

  #if defined( __BCPLUSPLUS__ ) || defined( __ZTC__ ) || defined( MPW ) || (defined( _MSC_VER ) && _MSC_VER >= 700)

	 #define _CPLUSPLUS_VER  2      // C++ version is AT&T C++ 2.x compatible

    #define     START_C_INCLUDE extern "C" {
    #define END_C_INCLUDE               }

  #else

	 #define _CPLUSPLUS_VER  1      // C++ version is only AT&T C++ 1.x compatible

    #define START_C_INCLUDE     
    #define END_C_INCLUDE       

  #endif

#else // not compiling under C++

  #define _CPLUSPLUS_VER  0

  #define START_C_INCLUDE       
  #define END_C_INCLUDE 

#endif /* __cplusplus */


/* Protect this file */
START_C_INCLUDE

#ifdef MACINTOSH
#ifndef PRECOMPILED_MACHDRS
#if !defined(THINK_C5) && !defined(__powerc)
#if !defined(nil)
	#define nil 0                           /* This must be defined before including machdrs.h or
CFront barfs. */
#endif  /* nil */
#endif  /* THINK_C5 */
#endif  /* PRECOMPILED_MACHDRS */
#endif  /* MACINTOSH */

/*----------------------------------------------------------------------*/
/* Bring in the Mac world.  Windows world comes last.                                   */
/*----------------------------------------------------------------------*/
#ifndef NO_WORLD                /* Define this to turn off include of the world. */

#ifdef MACINTOSH
#ifndef PRECOMPILE_HEADERS
#ifdef MPW
#include "machdrs.h"
#endif
#endif
#endif  /* MACINTOSH */

#ifdef WINDOWS                  
#include <Windows.h>            /* Win 3.1 change */
#endif

//#ifndef MACHINE_D
//#include "machine.h"                  /* Our own machine dependent extended defns */
//#endif        /* MACHINE_D */

#endif  /* NO_WORLD */



/*----------------------------------------------------------------------*/
/* Constants that define the environment in which a file has been               */
/* written. If ALD_PLATFORM is written into a file, software that later */
/* reads that file can compare the value to WIN_PLATFORM, MAC_PLATFORM, */
/* etc. to see where the file was created.                                                              */
/*                                                                                                                                              */
/* Don't use 0 as an environment id.  I can't remember why, but I think */
/* there is a good reason                                                                                               */
/*----------------------------------------------------------------------*/              
#define NULL_PLATFORM   0
#define WIN_PLATFORM    1
#define MAC_PLATFORM    2
#define OS2_PLATFORM    3

#ifdef WINDOWS
#define ALD_PLATFORM    WIN_PLATFORM
#endif

#ifdef MACINTOSH
#define ALD_PLATFORM    MAC_PLATFORM
#endif

#ifdef  OS2
#define ALD_PLATFORM    OS2_PLATFORM
#endif

#ifndef ALD_PLATFORM
#define ALD_PLATFORM    NULL_PLATFORM
#endif


/*----------------------------------------------------------------------*/
/* The following defines allow control over static/extern storage clas- */
/* sification to be controlled by overriding in universe.h                              */
/*                                                                                                                                              */
/* PLOCL        used in function prototypes only.                                                       */
/* LOCAL        used in functions themselves.                                                           */
/* PRIVATE      used in storage declarations.                                                           */
/*----------------------------------------------------------------------*/
#ifndef PLOCL
#if (defined(WINDOWS) || defined(DOS))
#define PLOCL   static
#endif
#ifdef  MACINTOSH
#define PLOCL
#endif
#endif  /* PLOCL */

#ifndef LOCAL
#define LOCAL   static
#endif

#ifndef PRIVATE
#define PRIVATE static
#endif

#ifndef _EXPORT
#ifdef __BORLANDC__
#define _EXPORT _export
#else
#define _EXPORT
#endif
#endif

/*----------------------------------------------------------------------*/
/*      CONST is a hook to prepare for declaraton of read-only data storage     */
/*      via the "const" option.                                                                                         */
/*----------------------------------------------------------------------*/
#ifndef CONST

#if defined (__cplusplus)
#if defined (MPW) || defined (__BORLANDC__) || defined (__ZTC__)
#define CONST   const
#else
#define CONST
#endif
#endif /* __cplusplus */

#if !defined (__cplusplus)
#define CONST
#endif

#endif


/*-------------------------------------------------------------------------*/
/*  Windows Only General Purpose Defines and TypeDefs                                                           */
/*-------------------------------------------------------------------------*/

#ifdef WINDOWS
#ifdef WIN32
	#define HGE
//      #undef CDECL
//      #define CDECL _cdecl
#else
	#define HGE     huge
#endif
#define CSDATA
#define FARDATA

#endif  /* WINDOWS */



/*-------------------------------------------------------------------------*/
/*  DOS Only General Purpose Defines and TypeDefs                                                               */
/*-------------------------------------------------------------------------*/

#ifdef DOS

#define HGE     huge
#define CSDATA
#define FARDATA
#define FAR far
#define NEAR near

#define TRUE    1
#define FALSE   0

#define VOID void
#define PMBool short
typedef unsigned char   BYTE;
typedef unsigned short  WORD;                   /* 16-bit unsigned integer. */
typedef long                            LONG;                   /* 32-bit signed integer. */
typedef unsigned long   DWORD;          /* 32-bit unsigned integer. */

typedef LONG    *LPLONG;
typedef BYTE    *LPBYTE;
typedef WORD    *LPWORD;
typedef DWORD   *LPDWORD;
typedef char    *LPSTR;                                 /* long pointer to string       */
typedef short   *LPINT;                         /* long pointer to short   */
typedef char    *NPSTR;                                 /* near pointer to string */
typedef char    *PSTR;                                  /* ptr to string */
typedef void    *LPVOID;

#define MAKELONG(a, b)      ((LONG)(((WORD)(a)) | (((DWORD)((WORD)(b))) << 16)))
#define LOWORD(l)           ((WORD)(l))
#define HIWORD(l)           ((WORD)(((DWORD)(l) >> 16) & 0xFFFF))
#define LOBYTE(w)           ((BYTE)(w))
#define HIBYTE(w)           ((BYTE)(((WORD)(w) >> 8) & 0xFF))


typedef int                                             *HANDLE;
typedef HANDLE              HWND;

typedef HANDLE              GLOBALHANDLE;
typedef HANDLE              LOCALHANDLE;

#define HFONT   HANDLE
#define HDC     HANDLE

/*      Many of these probably should be given their toolbox types, not the
 *      generic handle type.
 */
typedef HANDLE  HBITMAP;
typedef HANDLE  HWND;
typedef HANDLE  HCTRL;
typedef HANDLE  HCURSOR;
typedef HANDLE  HBRUSH;

typedef short   INTEGER;
typedef long    LONGINT;

#define MAKELONG(a, b)      ((LONG)(((WORD)(a)) | (((DWORD)((WORD)(b))) << 16)))
#define LOWORD(l)           ((WORD)(l))
#define HIWORD(l)           ((WORD)(((DWORD)(l) >> 16) & 0xFFFF))
#define LOBYTE(w)           ((BYTE)(w))
#define HIBYTE(w)           ((BYTE)(((WORD)(w) >> 8) & 0xFF))


/*      Many of these probably should be given their toolbox types, not the
 *      generic handle type.
 */
typedef HANDLE  HBITMAP;
typedef HANDLE  HWND;
typedef HANDLE  HCTRL;
typedef HANDLE  HCURSOR;
typedef HANDLE  HBRUSH;

typedef short   INTEGER;
typedef long    LONGINT;

#if !defined( __cplusplus )
#ifndef max
#define max(a,b)            (((a) > (b)) ? (a) : (b))
#endif
#ifndef min
#define min(a,b)            (((a) < (b)) ? (a) : (b))
#endif
#endif  /* __cplusplus */

#ifndef PASCAL
#define PASCAL pascal
#endif  /* PASCAL */

#ifndef CDECL
#define CDECL
#endif  /* CDECL */

typedef int (FAR PASCAL *FARPROC)();
typedef int (NEAR PASCAL *NEARPROC)();

#define LINT_ARGS                               /* Argument list macros */
#ifndef ARGS
#define ARGS(list) list
#endif
#define T_ARGS(list) list
#define PAD(name) short name;

typedef char Str255[255];
typedef Str255  Ald255;
typedef Str255  *pAld255;


#endif  /* DOS */



/*------------------------------------------------------------------*/
/* Macintosh Only General Purpose Defines.                                                                */
/* These are defined in Windows.h for the PC side.                                                */
/*------------------------------------------------------------------*/

#ifdef MACINTOSH

#ifndef CDECL
#define CDECL
#endif  /* CDECL */

#ifndef PASCAL
#define PASCAL pascal
#endif  /* PASCAL */


#define FAR
#define HGE
#define NEAR
#define CSDATA
#define FARDATA

#if !defined(TRUE)
	#define TRUE    1
#endif
#if !defined(FALSE)
	#define FALSE   0
#endif  

#define VOID void
#define PMBool short
typedef unsigned char   BYTE;
typedef unsigned short  WORD;                   /* 16-bit unsigned integer. */
typedef long                            LONG;                   /* 32-bit signed integer. */
typedef unsigned long   DWORD;          /* 32-bit unsigned integer. */

typedef LONG    *LPLONG;
typedef BYTE    *LPBYTE;
typedef WORD    *LPWORD;
typedef DWORD   *LPDWORD;
typedef char    *LPSTR;                                 /* long pointer to string       */
typedef short   *LPINT;                         /* long pointer to short   */
typedef char    *NPSTR;                                 /* near pointer to string */
typedef char    *PSTR;                                  /* ptr to string */
typedef void    *LPVOID;

#define MAKELONG(a, b)      ((LONG)(((WORD)(a)) | (((DWORD)((WORD)(b))) << 16)))
#define LOWORD(l)           ((WORD)(l))
#define HIWORD(l)           ((WORD)(((DWORD)(l) >> 16) & 0xFFFF))
#define LOBYTE(w)           ((BYTE)(w))
#define HIBYTE(w)           ((BYTE)(((WORD)(w) >> 8) & 0xFF))


#define HANDLE Handle           /* Mac specific handle types */
#define HFONT   HANDLE          /* not really used on the Mac   */
#define HDC     HANDLE          /* ditto                                                */

/*      Many of these probably should be given their toolbox types, not the
 *      generic handle type.
 */
typedef HANDLE  HBITMAP;
typedef HANDLE  HWND;
typedef HANDLE  HCTRL;
typedef HANDLE  HCURSOR;
typedef HANDLE  HBRUSH;

typedef short   INTEGER;
typedef long    LONGINT;

#ifdef MPW
#ifdef MPW3_0
typedef char    SignedByte;             /* MPW 3.1 defines this */
#endif
typedef short   OsErr;
#endif  /* MPW */

/*------------------------------------------------------------------*/
/* String types.  The string type Ald255 will be used on the Mac        */
/* instead of the Str255 type.  This is because MPW and Lightspeed      */
/* define them differently.                                                                                     */
/*------------------------------------------------------------------*/
typedef Str255  Ald255;
typedef Str255  *pAld255;

#define PSTRING( s )    (s)

/*------------------------------------------------------------------*/
/* In general, we have some problems with MPW/LSC compatibility,        */
/* where LSC expects to see the address of a variable and MPW           */
/* doesn't.                                                                                                                     */
/*------------------------------------------------------------------*/
#ifdef LSC3
#define ARRAY(a)        (&a)
#endif
#ifdef MPW
#define ARRAY(a)        (a)
#endif

#ifndef ARGS
#define ARGS(list) list
#endif
#define T_ARGS(list) list               /* -used to have to be defined as "()" */
#define PAD(name)

#endif  /* MACINTOSH */


/*------------------------------------------------------------------*/
/* Core General Purpose Defines.                                                                        */
/*------------------------------------------------------------------*/
typedef short RC;                                       /* standard Aldus return code */
#define SUCCESS ((RC) 0)
#define FAILURE ((RC) -1)

typedef char                            SINT;                   /* 8-bit, signed integer. */
typedef short                           SHORT;          /* 16-bit signed integer. */
typedef unsigned char   SSET;                   /* a set of up to 8 bits */
typedef unsigned short  SET;                    /* a set of up to 16 bits */
typedef unsigned long   LSET;                   /* a set of up to 32 bits */
typedef LONG                            XFORM_LONG;     /* in one ten-thousandth of a degree. */
typedef SHORT                           XFORM_SHORT;/* in one ten-thousandth of a degree. */
typedef PMBool    FAR             *LPBOOL;
typedef SHORT   FAR             *LPSHORT;
typedef LPSTR   FAR             *LPLPSTR;       /* long pointer to LPSTR */
typedef NPSTR   FAR             *LPNPSTR;       /* long pointer to NPSTR */
typedef void                            *PVOID;         /* generic untyped pointer      */
typedef float FAR                       *LPFLOAT;       

/*      These are needed in places that we want to be specific about storing
enumerated
	types, but we also need to be specific about how much space is allocated to it
	(in structures stored in the pub, for example).
*/
typedef BYTE                    BYTEENUM;
typedef WORD                    WORDENUM;
typedef DWORD                   DWORDENUM;

/* 7/11/90 - Now handling HUGE pointer types for our memory and
 * string operations, so here're the appropriate definitions, with some
 * extra junk in case someone else needs it...
 */
typedef char   HGE              *HPSTR;         /* huge pointer to string       */
typedef void   HGE              *HPVOID;
typedef WORD   HGE              *HPWORD;
typedef BYTE   HGE              *HPBYTE;
typedef SHORT  HGE              *HPSHORT;
typedef LONG   HGE              *HPLONG;
typedef short  HGE              *HPINT;     /* huge pointer to short   */


#define LPNULL                          ((void FAR *)0)         
#define LPNIL                           LPNULL
#define NPNULL                          ((void NEAR *)0)
#define PNULL                           ((void *)0)
													
#define ODD(X)                          ((X) & 1)
#define EVEN(X)                         (!((X) & 1))

/* Fixes MPW bug  8-13-91 */
#ifdef MPW      
#define COM(X)  (sizeof((X)) <= sizeof(WORD) ? (WORD)(~(X))  : (~(X)))
#else
/* XyWrite users:  hidden tilda on next line */
#define COM(X)  (~(X))                  
#endif

#define YES                     TRUE
#define NO                      FALSE
#define FORWARD extern                                  /* for forward references within module */
#define FOREVER for(;;)                                 /* infinite loop */
#define LOOP            FOREVER

#ifndef WIN32
	#ifndef MAXSHORT
		#define MAXSHORT (0x7FFF)               /* maximum 16-bit signd int     */
	#endif
	#ifndef MAXWORD
		#define MAXWORD ((WORD)0xFFFF)  /* maximum 16-bit unsigned int  */
	#endif
	#ifndef MAXLONG                     /* (conflicts with TC5) */
		#define MAXLONG 0x7FFFFFFFL             /* maximum 32-bit signed int    */
	#endif
	#ifndef MAXDWORD
		#define MAXDWORD ((DWORD)0xFFFFFFFFL)   /* maximum 32-bit unsigned int  */
	#endif
#endif  // WIN32

#ifndef VAR_ARGS                                                        /* variable length argument lists */
#define VAR_ARGS ...
#endif

#ifndef NO_ARGS
#ifdef  __cplusplus                     /* name(...) in C++ means name() in C */
#define NO_ARGS ...
#else
#define NO_ARGS
#endif
#endif

#define IN                                              /* Procedure parameter commenting aids */
#define OUT

/*----------------------------------------------------------------------
 *      Register definitions: REG should be used on entries that will be register
 *                                                variables in both the PC and MAC environments, while
 *                                                REGM should be used on entries that will be register
 *                                                varables on the MAC only. Rumor has it that for Windows
 *                                                only 2 register variables exist, while the MAC has
 *                                                allowances for 3 pointer and 5 data register instances.
 * ----------------------------------------------------------------------*/
#define REG register            /* PC and MAC */

#ifdef MACINTOSH
#define REGM register   /* MAC only */
#else
#define REGM
#endif  /* MACINTOSH */



typedef char    FAR     *FOREIGN;       /* someone else's private datatype */
typedef HANDLE  FAR     *LPHANDLE;
typedef WORD                    RESID;          /* generic resource identifier */


#ifdef NULL     /* Some std include define this for us.  Do it our way */
#undef NULL
#endif

#ifdef MACINTOSH
#ifndef __cplusplus
#define NULL    0L
#else
/* mof 7/28/89 - define null under __cplusplus to be untyped.  This
 *      allows assignments of null to pointer variables without casting
 *      which would be required by new c++ compiler so long as null is
 *      typed as a long.  C++ should make any necessary coercions, so
 *      this should be safe.
 */
#define NULL    0
#endif  /* __cplusplus */
#else
#define NULL    0
#endif  /* MACINTOSH */



/*----------------------------------------------------------------------*/
/*      Some generic macros.                                                                                            */
/*----------------------------------------------------------------------*/
#define xmin( a, b )    (((a)<(b))?(a):(b))
#define xmax( a, b )    (((a)>(b))?(a):(b))
#define xabs( a )               (((a)>=0)?(a):(-a))
#define ABS( a )                xabs( a )
#define MIN( a, b )             xmin( a, b )
#define MAX( a, b )             xmax( a, b )


/*----------------------------------------------------------------------*/
/* These are the same macros as defined in stdarg.h except                              */
/* they use FAR pointers.                                                                                               */
/*----------------------------------------------------------------------*/
typedef char FAR *va_far_list;
#define va_far_start(ap,v) ap = (va_far_list)&v + sizeof(v)
#define va_far_arg(ap,t)        ((t FAR *)(ap += sizeof(t)))[-1]
#define va_far_end(ap)  ap = NULL;



/*----------------------------------------------------------------------*/
/* mnemonics for relational operators                                                                                           */
/* Left in for compatibility.                                                                                                           */
/* I don't think anyone should be using these.                                                                  */
/*----------------------------------------------------------------------*/
#define EQ      ==
#define GE      >=
#define GT      >
#define LE      <=
#define LT      <
#define NE      !=



/*-------------------------------------------------------------------------*/
/*  Windows Edge Defines and Typedefs.                                                                                                  */
/*-------------------------------------------------------------------------*/

#ifdef WINDOWS

#define PORT    HDC                             /* Windows specific handle types */
#define WIND    HWND
#define HCTRL   HWND

#define LINT_ARGS                               /* Argument list macros */
#ifndef ARGS
#define ARGS(list) list
#endif
#define T_ARGS(list) list
#define PAD(name) short name;

#endif  /* WINDOWS */



/*----------------------------------------------------------------------*/
/* We don't want to really do the following, but if we don't, we end    */
/* up breaking about 90% of PageMaker's files which use the types               */
/* and defs from this file and assume they're in aldtypes.h.  Alamo             */
/* on the other hand, doesn't.                                                                                  */
/* For now, let those who don't want this turn it off by defining               */
/* NOALDGEOM from their universe.h                                                                              */
/*----------------------------------------------------------------------*/
//#ifndef ALDGEOM_D
//#ifndef NO_ALDGEOM
//#include "aldgeom.h"
//#endif
//#endif



/*----------------------------------------------------------------------*/
/* You should only use these if you REALLY always want to use Pascal    */
/* calling conventions.  On the Mac, it's more efficient to use C               */
/* calling conventions.  On WINDOWS, Pascal is better.  The better way  */
/* to do this is to not use these definitions below but to let the              */
/* compiler determine which conventions to use.                                                 */
/* For historical reasons, these are left in, but you can override this */
/* by defining PASCAL_CALL in your universe.h file to be the way you    */
/* want it.  For instance, '#define PASCAL_CALL(type) type' would give  */
/* you the compiler default calling convention.  On the Mac you'd get   */
/* C conventions.  On the PC you could then use the -Gc switch to force */
/* Pascal.                                                                                                                              */
/*----------------------------------------------------------------------*/
#ifndef PASCAL_CALL                     /* You can override this by defining in universe.h */
#if (defined(WINDOWS) || defined(DOS))
#define PASCAL_CALL(type)       type PASCAL
#endif
#ifdef MACINTOSH
#define PASCAL_CALL(type)       PASCAL type
#endif
#endif  /* PASCAL_CALL */

#ifndef BOOL_PASCAL
#define BOOL_PASCAL     PASCAL_CALL(PMBool)
#endif /* BOOL_PASCAL */

#ifndef RC_PASCAL
#define RC_PASCAL       PASCAL_CALL(RC)
#endif /* RC_PASCAL */

#ifndef LPVOID_PASCAL
#define LPVOID_PASCAL PASCAL_CALL(LPVOID)
#endif /* LPVOID_PASCAL */

#ifndef WORD_PASCAL
#define WORD_PASCAL PASCAL_CALL(WORD)
#endif /* WORD_PASCAL */

#ifndef DWORD_PASCAL
#define DWORD_PASCAL PASCAL_CALL(DWORD)
#endif /* DWORD_PASCAL */

#ifndef void_PASCAL
#define void_PASCAL PASCAL_CALL(void)
#endif /* void_PASCAL */

#ifndef LPSTR_PASCAL
#define LPSTR_PASCAL PASCAL_CALL(LPSTR)
#endif /* LPSTR_PASCAL */

#ifndef RIX_PASCAL
#define RIX_PASCAL PASCAL_CALL(RIX)
#endif /* RIX_PASCAL */

#ifndef RID_PASCAL
#define RID_PASCAL PASCAL_CALL(RID)
#endif /* RID_PASCAL */


/* These are really dumb. */

#ifndef BOOL_FAR_PASCAL
#define BOOL_FAR_PASCAL PASCAL_CALL(PMBool) FAR
#endif

#ifndef RC_FAR_PASCAL
#define RC_FAR_PASCAL PASCAL_CALL(RC) FAR
#endif

#ifndef SHORT_FAR_PASCAL
#define SHORT_FAR_PASCAL PASCAL_CALL(SHORT) FAR
#endif

#ifndef void_FAR_PASCAL
#define void_FAR_PASCAL PASCAL_CALL(void) FAR
#endif

#ifndef LPSTR_FAR_PASCAL
#define LPSTR_FAR_PASCAL PASCAL_CALL(LPSTR) FAR
#endif

#ifndef WORD_FAR_PASCAL
#define WORD_FAR_PASCAL PASCAL_CALL(WORD) FAR
#endif

#ifndef BOOL_CDECL
#if (defined (WINDOWS) || defined(DOS) )
#define BOOL_CDECL PMBool CDECL
#endif
#ifdef MACINTOSH
#define BOOL_CDECL CDECL PMBool
#endif
#endif


END_C_INCLUDE

#endif  /* ALDTYPES_D */



