/*
 *--- PageMakerCommands.h -------------------------------------------
 * Copyright 1990-95 Adobe Systems, Inc.  All rights reserved.
 *
 *  This contains the declarations of all the internal PageMaker
 *	commands and queries.
 *
 *
 *-------------------------------------------------------------------
 */

#ifndef __PageMakerCommands__
#define __PageMakerCommands__

#ifdef __MWERKS__
#pragma once
#endif

//---------------------------------------------------------
//  Command declarations:
//  --------------------
//
//  These #defines form the basis of the command declarations.
//---------------------------------------------------------

// Command Sections:
#define pm_nullcommand  0                 // start of cmds
#define pm_maxcommand   pm_nullcommand + 1999   // end of cmds.

	// Query Section:
#define pm_a_commands   pm_nullcommand + 1100
#define pm_b_commands   pm_nullcommand + 1135
#define pm_c_commands   pm_nullcommand + 1170
#define pm_d_commands   pm_nullcommand + 1205
#define pm_e_commands   pm_nullcommand + 1240
#define pm_f_commands   pm_nullcommand + 1275
#define pm_g_commands   pm_nullcommand + 1310
#define pm_h_commands   pm_nullcommand + 1345
#define pm_i_commands   pm_nullcommand + 1380
#define pm_j_commands   pm_nullcommand + 1415
#define pm_k_commands   pm_nullcommand + 1450
#define pm_l_commands   pm_nullcommand + 1485
#define pm_m_commands   pm_nullcommand + 1520
#define pm_n_commands   pm_nullcommand + 1555
#define pm_o_commands   pm_nullcommand + 1590
#define pm_p_commands   pm_nullcommand + 1625
#define pm_q_commands   pm_nullcommand + 1660
#define pm_r_commands   pm_nullcommand + 1695
#define pm_s_commands   pm_nullcommand + 1730
#define pm_t_commands   pm_nullcommand + 1765
#define pm_u_commands   pm_nullcommand + 1800
#define pm_v_commands   pm_nullcommand + 1835
#define pm_w_commands   pm_nullcommand + 1870
#define pm_x_commands   pm_nullcommand + 1905
#define pm_y_commands   pm_nullcommand + 1940
#define pm_z_commands   pm_nullcommand + 1975

#define pm_drawing_cmds   pm_nullcommand + 800
#define pm_edit_menu    pm_nullcommand + 100
#define pm_element_menu   pm_nullcommand + 500
#define pm_file_menu    pm_nullcommand + 1
#define pm_misc_cmds    pm_nullcommand + 1000
#define pm_object_cmds    pm_nullcommand + 900
#define pm_options_menu   pm_nullcommand + 200
#define pm_page_menu    pm_nullcommand + 300
#define pm_textedit_cmds  pm_nullcommand + 700
#define pm_type_menu    pm_nullcommand + 400
#define pm_windows_menu   pm_nullcommand + 600
//
// Note: pm_new_commands really started at 900+12, 
// so as not to interfere with pm_object_commands
//
#define pm_new_commands   pm_nullcommand + 900


typedef enum
{
	//---------------------------------------------------------
	//	Command Section: Organized alphabetically
	//---------------------------------------------------------
	// 'A' Commands:
	pm_addition 			= (pm_misc_cmds + 0),
	pm_addpreview 			= (pm_new_commands + 32),
	pm_addword 				= (pm_a_commands + 0),
	pm_alignment 			= (pm_type_menu + 21),
	pm_autoflow 			= (pm_options_menu + 7),
	pm_addprinterstyle 		= (	pm_a_commands + 1),
	pm_assignlayer 			= (pm_a_commands + 2),
	pm_attachcontent 		= (pm_a_commands + 4),

	// 'B' Commands:
	pm_basedon 				= (pm_type_menu + 25),
	pm_blackattributes 		= (pm_b_commands + 0),
	pm_book 				= (pm_file_menu + 14),
	pm_box 					= (pm_drawing_cmds + 1),
	pm_bringforward 		= (pm_b_commands + 1),
	pm_bringtofront 		= (pm_b_commands + 2),
	pm_breaklinks 			= (pm_b_commands + 3),


	// 'C' Commands:
	pm_case 				= (pm_type_menu + 7),
	pm_cascade 				= (pm_windows_menu + 6),
	pm_change 				= (pm_c_commands + 0),
	pm_changeall 			= (pm_c_commands + 2),
	pm_changeparaattr 		= (pm_c_commands + 3),
	pm_changetypeattr1 		= (pm_c_commands + 6),
	pm_changetypeattr2 		= (pm_c_commands + 7),
	pm_changeenv 			= (pm_new_commands + 12),
	pm_changenext 			= (pm_c_commands + 1),
	pm_changewindow 		= (pm_c_commands + 5),
	pm_clear 				= (pm_edit_menu + 4),
	pm_close 				= (pm_file_menu + 2),
	pm_closestory 			= (pm_c_commands + 4),
	pm_color 				= (pm_object_cmds + 0),
	pm_colorpalette 		= (pm_windows_menu + 3),
	pm_columnguides 		= (pm_options_menu + 6),
	pm_controlpalette 		= (pm_windows_menu + 4),
	pm_copy 				= (pm_edit_menu + 1),
	pm_createindex 			= (pm_options_menu + 10),
	pm_createtoc 			= (pm_options_menu + 12),
	pm_crop 				= (pm_object_cmds + 10),
	pm_cropimageatframe 	= (pm_c_commands + 8),
	pm_croprect 			= (pm_c_commands + 9),
	pm_cut 					= (pm_edit_menu + 0),
	pm_convertenhmetafile 	= (pm_misc_cmds + 15),

	// 'D' Commands:
	pm_defaultdir 			= (pm_new_commands + 20),
	pm_definecolor 			= (pm_new_commands + 13),
	pm_defineink 			= (pm_new_commands + 44),
	pm_delete 				= (pm_object_cmds + 4),
	pm_deletehoriz 			= (pm_misc_cmds + 4),
	pm_deleteprivatedata 	= (pm_d_commands + 2),
	pm_deleterulerguides 	= (pm_misc_cmds + 6),
	pm_deletevert 			= (pm_misc_cmds + 5),
	pm_deselect 			= (pm_object_cmds + 1),
	pm_dictionary 			= (pm_type_menu + 11),
	pm_displayspecial 		= (pm_d_commands + 0),
	pm_displaystylenames 	= (pm_d_commands + 1),
	pm_deletemasterpage 	= (	pm_d_commands + 5),
	pm_definemasterpage 	= (pm_d_commands + 6),
	pm_defaultprintclrspace = (pm_d_commands + 7),
	pm_deletelayer 			= (pm_d_commands + 8),
	pm_deleteunusedlayers 	= (pm_d_commands + 9),
	pm_dragselect 			= (pm_d_commands + 10),
	pm_dragselectextend 	= (pm_d_commands + 11),
	pm_deletecontent 		= (pm_d_commands + 12),
	pm_downloadwebcontent	= (pm_d_commands + 13),

	// 'E' Commands:
	pm_editcolor 			= (pm_element_menu + 7),
	pm_editlayout 			= (pm_e_commands + 0),
	pm_editoriginal 		= (pm_edit_menu + 11),
	pm_editstory 			= (pm_edit_menu + 10),
	pm_evaluate_text 		= (pm_nullcommand + 4900),
	pm_execute_text 		= (pm_nullcommand + 1900),
	pm_exit 				= (pm_file_menu + 23),
	pm_export 				= (pm_file_menu + 7),

	// 'F' Commands:
	pm_fillandline 			= (pm_new_commands + 15),
	pm_fillstyle 			= (pm_element_menu + 1),
	pm_find					= (pm_f_commands + 0),
	pm_findparaattr 		= (pm_f_commands + 1),
	pm_findtypeattr1        = (pm_f_commands + 4),
	pm_findtypeattr2		= (pm_f_commands + 5),
	pm_findnext 			= (pm_f_commands + 2),
	pm_findwindow 			= (pm_f_commands + 3),
	pm_font 				= (pm_type_menu + 0),
	pm_fontdrawing 			= (pm_edit_menu + 7),
	pm_framecontentpos 		= (pm_f_commands + 6),
	pm_frameinset 			= (pm_f_commands + 7),

	// 'G' Commands:
	pm_group 				= (pm_g_commands + 0),
	pm_guidehoriz 			= (pm_misc_cmds + 2),
	pm_guides 				= (pm_options_menu + 3),
	pm_guidevert 			= (pm_misc_cmds + 3),
	pm_goback 				= (pm_g_commands + 1),
	pm_goforward 			= (pm_g_commands + 2),


	// 'H' Commands:
	pm_hyphenation 			= (pm_type_menu + 20),
	pm_hyperjump 			= (pm_h_commands + 0),
	pm_hyperlinkpalette 	= (pm_h_commands + 1),

	// 'I' Commands:
	pm_import 				= (pm_file_menu + 8),
	pm_indents 				= (pm_type_menu + 18),
	pm_indexauto 			= (pm_options_menu + 8),
	pm_indexautoname 		= (pm_options_menu + 9),
	pm_indexformat 			= (pm_options_menu + 11),
	pm_inknd 				= (pm_i_commands + 0),
	pm_insertpages 			= (pm_page_menu + 3),
	pm_invalidaterect 		= (pm_misc_cmds + 12),
	pm_imagesaveforsep 		= (pm_i_commands + 1),
	pm_imagesaveas 			= (pm_i_commands + 2),
	pm_inserttoken 			= (pm_i_commands + 3),

	// 'J' Commands:
	// 'K' Commands:
	pm_kern 				= (pm_textedit_cmds + 7),
	pm_kerntext 			= (pm_textedit_cmds + 8),

	// 'L' Commands:
	pm_leading 				= (pm_type_menu + 2),
	pm_letterspace 			= (pm_type_menu + 16),
	pm_line					= (pm_drawing_cmds + 0),
	pm_linestyle			= (pm_element_menu + 0),
	pm_linkoptions			= (pm_element_menu + 9),
	pm_lock					= (pm_l_commands + 0),
	pm_lockguides			= (pm_options_menu + 5),
	pm_layeroptions			= (	pm_l_commands + 1),
	pm_locklayers			= (pm_l_commands + 2),
	pm_layadjopts			= (pm_l_commands + 3),
	pm_linkframes			= (pm_l_commands + 4),
	pm_layerpalette			= (pm_l_commands + 5),

	// 'M' Commands:
	pm_manualkerning		= (pm_textedit_cmds + 6),
	pm_mask					= (pm_element_menu + 11),
	pm_masterguides			= (pm_page_menu + 6),
	pm_masteritems			= (pm_page_menu + 5),
	pm_measureunits			= (pm_edit_menu + 6),
	pm_minisave				= (pm_file_menu + 4),
	pm_move					= (pm_object_cmds + 8),
	pm_movecolumn			= (pm_misc_cmds + 7),
	pm_multiplepaste		= (pm_edit_menu + 3),
	pm_multpasteoffset		= (pm_m_commands + 0),
	pm_masterpage			= (pm_m_commands + 6),
	pm_masterpagepalette	= (pm_m_commands + 7),
	pm_movelayer			= (pm_m_commands + 8),

	// 'N' Commands:
	pm_new					= (pm_file_menu + 0),
	pm_newstory				= (pm_textedit_cmds + 0),
	pm_newstorysized		= (pm_n_commands + 0),
	pm_nextstyle			= (pm_type_menu + 26),
	pm_nudge				= (pm_object_cmds + 9),
	pm_displaynonprinting	= (pm_n_commands + 1),
	pm_nonprinting			= (pm_n_commands + 2),
	pm_newlayer				= (pm_n_commands + 3),

	// 'O' Commands:
	pm_open					= (pm_file_menu + 1),
	pm_openstory			= (pm_o_commands + 0),
	pm_oval					= (pm_drawing_cmds + 2),

	// 'P' Commands:
	pm_page					= (pm_page_menu + 1),
	pm_pagemargins			= (pm_file_menu + 11),
	pm_pagenumbers			= (pm_file_menu + 13),
	pm_pageoptions			= (pm_file_menu + 12),
	pm_pagesize				= (pm_file_menu + 10),
	pm_paintwindow			= (pm_new_commands + 42),
	pm_palettedn			= (pm_misc_cmds + 13),
	pm_paletteup			= (pm_misc_cmds + 14),
	pm_paraoptions			= (pm_type_menu + 10),
	pm_paraspace			= (pm_type_menu + 9),
	pm_paste				= (pm_edit_menu + 2),
	pm_pastelink			= (pm_new_commands + 17),
	pm_pastespecial			= (pm_new_commands + 18),
	pm_pickcolor			= (pm_new_commands + 38),
	pm_place				= (pm_file_menu + 9),
	pm_placesized			= (pm_p_commands + 3),
	pm_placenext			= (pm_object_cmds + 5),
	pm_position				= (pm_type_menu + 6),
	pm_polygon				= (pm_drawing_cmds + 3),
	pm_polygonattribs		= (pm_drawing_cmds + 4),
	pm_preferences			= (pm_edit_menu + 9),
	pm_print				= (pm_file_menu + 15),
	pm_printerresol			= (pm_p_commands + 5),
	pm_printcomposite		= (pm_file_menu + 19),
	pm_printoptions1		= (pm_file_menu + 17),
	pm_printoptions2		= (pm_file_menu + 18),
	pm_printpostscript		= (pm_file_menu + 21),
	pm_printsetup			= (pm_file_menu + 16),
	pm_printspotcolors		= (pm_file_menu + 20),
	pm_printcolor			= (pm_new_commands + 23),
	pm_printdoc				= (pm_new_commands + 24),
	pm_printink				= (pm_new_commands + 25),
	pm_printoptions			= (pm_new_commands + 26),
	pm_printoptionsps		= (pm_new_commands + 27),
	pm_printpaperps			= (pm_new_commands + 35),
	pm_printto				= (pm_new_commands + 36),
	pm_privatedata			= (pm_p_commands + 0),
	//ulong vendID, ulong addnID, word targetclass (convert to CIX), ulong usercontext, #records to store, ulong targetRID, BOOL changeit, handle to data
	pm_privatestring		= (pm_p_commands + 1),
	//ulong vendID, ulong addnID, word targetclass (convert to CIX), ulong usercontext, #records to store, ulong targetRID, BOOL changeit, pdata string
	pm_printfeature			= (pm_new_commands + 43),
	pm_printerstyle			= (pm_p_commands + 4),

	pm_polygontype			= (pm_p_commands + 7),
	pm_polygonmiterlimit	= (pm_p_commands + 8),
	pm_polygonvertices		= (pm_p_commands + 9),
	pm_createpolygon		= (pm_p_commands + 10),
	pm_reversepolyvertices	= (pm_p_commands + 11),
	pm_appendvertices		= (pm_p_commands + 12),
	pm_polygonjoin			= (pm_p_commands + 13),


	pm_printscreenrgbs		= (pm_new_commands + 46),
	pm_printepspreviews		= (pm_new_commands + 47),
	pm_pasteremembers		= (pm_p_commands + 6),
	pm_printdevicindpntcolor = (pm_p_commands + 14),


	// 'Q' Commands:
	pm_quit					= (pm_file_menu + 22),

	// 'R' Commands:
	pm_redraw				= (pm_misc_cmds + 8),
	pm_reflect				= (pm_new_commands + 28),
	pm_releaseacrobathandle = (pm_r_commands + 2),
	pm_relink				= (pm_element_menu + 8),
	pm_removecolor			= (pm_new_commands + 16),
	pm_removepages			= (pm_page_menu + 4),
	pm_removestyle			= (pm_type_menu + 27),
	pm_removeunusedcolors	= (pm_new_commands + 45),
	pm_removeword			= (pm_r_commands + 0),
	pm_renderclip			= (pm_new_commands + 19),
	pm_resize				= (pm_object_cmds + 6),
	pm_resizepct			= (pm_object_cmds + 7),
	pm_restorecolor			= (pm_element_menu + 13),
	pm_revert				= (pm_file_menu + 6),
	pm_rotate				= (pm_new_commands + 34),
	pm_rotation				= (pm_element_menu + 4),
	pm_roundedcorners		= (pm_element_menu + 6),
	pm_ruleabove			= (pm_type_menu + 12),
	pm_rulebelow			= (pm_type_menu + 13),
	pm_ruleoptions			= (pm_type_menu + 14),
	pm_rulers				= (pm_options_menu + 0),
	pm_removeprinterstyle	= (pm_r_commands + 1),
	pm_renamemasterpage		= (pm_r_commands + 3),
	pm_recorder				= (pm_r_commands + 4),

	// 'S' Commands:
	pm_save					= (pm_file_menu + 3),
	pm_saveas				= (pm_file_menu + 5),
	pm_scroll				= (pm_misc_cmds + 1),
	pm_scrollbars			= (pm_windows_menu + 1),
	pm_select				= (pm_object_cmds + 2),
	pm_selectall			= (pm_edit_menu + 5),
	pm_selectextend			= (pm_object_cmds + 3),
	pm_selectid				= (pm_s_commands + 0),
	pm_selectidextend		= (pm_s_commands + 1),
	pm_sendbackward			= (pm_s_commands + 5),
	pm_sendtoback			= (pm_element_menu + 3),
	pm_sendtopage			= (pm_misc_cmds + 11),
	pm_settextcursor		= (pm_new_commands + 37),
	pm_setwidth				= (pm_type_menu + 3),
	pm_showpages			= (pm_page_menu + 2),
	pm_showerroralert		= (pm_new_commands + 40),
	pm_size					= (pm_type_menu + 1),
	pm_sizebump				= (pm_textedit_cmds + 5),
	pm_skew					= (pm_new_commands + 29),
	pm_snaptoguides			= (pm_options_menu + 4),
	pm_snaptorulers			= (pm_options_menu + 1),
	pm_spaceoptions			= (pm_type_menu + 17),
	pm_spell				= (pm_s_commands + 2),
	pm_spellwindow			= (pm_s_commands + 3),
	pm_storyeditpref		= (pm_edit_menu + 8),
	pm_style				= (pm_type_menu + 22),
	pm_stylebegin			= (pm_type_menu + 23),
	pm_styleend				= (pm_type_menu + 24),
	pm_stylepalette			= (pm_windows_menu + 2),
	pm_suppressautosave		= (pm_s_commands + 4),
	pm_suppresspreview		= (pm_new_commands + 30),
	pm_suppresspaldraw		= (pm_new_commands + 41),
	pm_suppresspi			= (pm_new_commands + 39),
	pm_suppressprint		= (pm_new_commands + 31),
	pm_saveasmasterpage		= (	pm_s_commands + 6),
	pm_setepsfontscan		= (pm_s_commands + 7),
	pm_savestatusoff		= (pm_s_commands + 8),
	pm_scriptpal			= (pm_s_commands + 9),
	pm_selectlayer			= (pm_s_commands + 10),
	pm_showlayers			= (pm_s_commands + 11),
	pm_separatecontent		= (pm_s_commands + 12),
	pm_scriptabort			= (pm_s_commands + 13),

	// 'T' Commands:
	pm_tabs					= (pm_type_menu + 19),
	pm_textcursor			= (pm_textedit_cmds + 3),
	pm_textedit				= (pm_textedit_cmds + 1),
	pm_textenter			= (pm_textedit_cmds + 4),
	pm_textselect			= (pm_textedit_cmds + 2),
	pm_textwrap				= (pm_element_menu + 5),
	pm_tintselection		= (pm_o_commands + 1),
	pm_textwrappoly			= (	pm_object_cmds + 11),
	pm_toolbox				= (pm_windows_menu + 0),
	pm_tool					= (pm_t_commands + 1),
	pm_nobreak				= (pm_t_commands + 2),
	pm_track				= (pm_type_menu + 4),
	pm_typeoptions			= (pm_type_menu + 8),
	pm_typestyle			= (pm_type_menu + 5),
	pm_trapsettings			= (	pm_t_commands + 0),
	pm_tile					= (pm_windows_menu + 5),
	pm_toggleframe			= (pm_t_commands + 3),
	pm_targetlayer			= (pm_t_commands + 4),

	// 'U' Commands:
	pm_unlink				= (pm_element_menu + 10),
	pm_ungroup				= (pm_u_commands + 0),
	pm_unmask				= (pm_element_menu + 12),
	pm_unselect				= (pm_u_commands + 1),
	pm_unselectid			= (pm_u_commands + 2),

	// 'V' Commands:
	pm_view					= (pm_page_menu + 0),

	// 'W' Commands:
	pm_window				= (pm_new_commands + 33),
	pm_wordspace			= (pm_type_menu + 15),

	// 'Z' Commands:
	pm_zerolock				= (pm_options_menu + 2),
	pm_zeropoint			= (pm_misc_cmds + 9),
	pm_zeropointreset		= (pm_misc_cmds + 10)

} ePMCommand;

#endif

// end of PageMakerCommands.h
