/*
 *--- PMTypes.h --------------------------------------------
 * Copyright (C) 1990-95 Adobe Systems, Inc.  All rights reserved.
 *
 * Standard types and definitions for PageMaker 6.0.
 *
 * This header file is designed to be used with the following
 * compilers and development operating systems:
 *
 * Mac OS (System 7): Metrowerks CodeWarrior CW7 or later
 *            Windows 95: Microsoft Visual C++ 2.0 or later
 *
 *
 *
 *-----------------------------------------------------------------
 */

#ifndef __PageMakerTypes__
#define __PageMakerTypes__

// Interface version
#define ADOBE_VER 0x0300

// Standard PageMaker PlugIn return code
typedef short PMErr;    
typedef PMErr PMXErr;  //new and old Plug-ins had different names for the return code

#ifdef __MWERKS__
#pragma once
	#if __MC68K__ || __POWERPC__
	#ifndef MACINTOSH
		#define MACINTOSH 1
	#endif
		#include <Types.h>
	#endif
	#if __INTEL__
		#define WINDOWS 1
	#endif
#endif

#ifndef MACINTOSH
	#ifndef WINDOWS
		#define WINDOWS 1
	#endif
#endif

#ifdef WINDOWS
	#include <windows.h>
#endif //WINDOWS

// Plugin library properties. It is a LONG (32 bit) flag
// interface version 0x300 only, This should be defined
// in the first 4 bytes in the ADN1 resource.
#define kNoProp                 0x0000          // plugin library has no property
#define kStayInMem              0x0001          // plugin library to stay in memory
#define kLibRegister            0x0002          // call plugin library to register
#define kDisablePMEvent                 0x0004                  // plugin library will not receive kPMEvent
#define kDisablePMSysEvent              0x0008                  // plugin library will not receive kPMSysEvent
#define kDisableNonCQEvent         0x0010          // plugin library will not receive kPMEvent when processing Commands and Queries

//---------------------------------------------------------
//      PageMaker op-codes (used to be kAdnXXX constants)
//---------------------------------------------------------
typedef enum 
{       
	kPMNullOperation        = 0,
	kPMLoad                         = 1,
	kPMUnload                       = 2,
	kPMRegister                     = 3,
	kPMCleanup                      = 4,
	kPMShutdown                     = 5,
	kPMInvoke                       = 6,
	kPMEvent                        = 7,    // Event notification
	kPMSysEvent                     = 8,
	kPMAcquireInterface                             = 9,
	kPMReleaseInterface                             = 10,
	kPMFiller                                               = 1000   // Force op-codes to be two bytes
} ePMOpcode;

// Plugin properties. It is a LONG (32 bit) flag
// Note: These replace KAdnXXXXX for Plug-ins created under previous
// versions of the SDK. 
typedef enum
{
	kPlugInDontDisplay              = 0x00,
	kPlugInDisplayInMenu    = 0x01,
	kPlugInColorPicker              = 0x02,
	kPlugInLayoutState              = 0x04,
	kPlugInStoryEditState   = 0x08,
	kPlugInNoPubState               = 0x10,
	kPlugInEPSFontInfo              = 0x20,
	kPlugInRGBInfo                  = 0x40,
	kAdnAllStates                   = 0xFF0
} ePluginProperty;

#ifdef __cplusplus
//      Structure passed from PageMaker
class CIInterfaceManager;

class CIInterface
{
public:
	virtual ~CIInterface() {};
// leave empty to use default - virtual base class derived from this
// cannot have defined constructor and destructor
};

typedef struct _PMMessage
{
	CIInterfaceManager      *pInterfaceMgr;         //      InterfaceManager pointer
	ePMOpcode                       opCode;                         //      PageMaker op-code       
	long                            id;                                     //      id based on the opCode
	void                            *pPlugInData;           //      Plugin run-time private data
	void                            *pPMData;                       //      PageMaker data. An example would 
											//      a pointer to PMEvent.
} PMMessage;

//      New PlugIn entry proc
typedef PMXErr ((*fnPlugInProc) (PMMessage *));
#endif

typedef short PMBool;

#if defined(false)
	#if false != 0
		#error A different 'false'  is already #defined
	#else
		#undef false
	#endif
#endif
#define false (PMBool)0

#if defined(true)
	#if true != 1
		#error A different 'true' is already #defined
	#else
		#undef true
	#endif
#endif
#define true (PMBool)1


//      Measurement system constants, based on TWIPS (twentieths of a pica-point):

#define kTwipsPerInch           ((float) 1440.0)
#define kTwipsPerCentimeter ((float) (72000.0 / 127.0))
#define kTwipsPerMillimeter     ((float) (7200.0 / 127.0))
#define kTwipsPerPicaPoint      ((float) 20.0)                          // pica-point - PRIMARY definition
#define kTwipsPerPica           ((float) 240.0)                         // PICAPOINT * 12
#define kTwipsPerCicero         ((float) (6394.0 / 25.0))
#define kTwipsPerDidot          ((float) (12000.0 / 563.0))


// SetRect, UnionRect are the functions both defined in Macintosh and PC.  We define the macros here
// to solve the problem of different parameter type of the platforms.
//
// Notice that the order of the parameters under MacOS and WIndows are different!!!

#ifdef WINDOWS

	#define SETRECT(rect, left, top, right, bottom) SetRect((LPRECT)(rect), (int)(left), (int)(top), (int)(right), (int)(bottom))
	#define UNIONRECT(rect1, rect2, resultRect)             UnionRect((LPRECT)(resultRect), (LPRECT)(rect1), (LPRECT)(rect2))
	#define EMPTYRECT(bbox) ((bbox)->bottom <= (bbox)->top || (bbox)->right <= (bbox)->left)
	
	#define PMHandle void *
	#define MAKEHDL(x) LOWORD(x)

#endif

#ifdef MACINTOSH

	#define SETRECT(rect, left, top, right, bottom) SetRect((Rect *)(rect), (short)(left), (short)(top), (short)(right), (short)(bottom))
	#define UNIONRECT(rect1, rect2, resultRect)             UnionRect((Rect *)(rect1), (Rect *)(rect2), (Rect *)(resultRect))
	#define EMPTYRECT(bbox) EmptyRect((Rect *)(bbox))
	
	#define PMHandle Handle
	#define MAKEHDL(x)  (x)

#endif


//--- Measurement units ----------------------------------------------------------
// ePMUnits describe the constants used to describe different units in PageMaker.
//--------------------------------------------------------------------------------
typedef enum
{
	kMUNull                         = 0,
	kMUInches                       = 1,
	kMUDecInches            = 2,
	kMUCentimeters          = 3,
	kMUPicas                        = 4,
	kMUPoints                       = 5,
	kMUCiceros                      = 6,
	kMUTwips                        = 7,
	kMUFiller                       = 1000          // force enum to be two bytes
} ePMUnits;

//---------------------------------------------------------
// This typedef defines the categories for saving or retrieving private
// data from a PageMaker document.  See PrivateData in Chapter 9 or
// GetPrivateData in Chapter 10.
//---------------------------------------------------------
typedef enum
{
	class_dontcare          = -2,
	class_object            = 25,           
	class_page                      = 5,
	class_story                     = 26,
	class_pub                       = 24,   
	class_masterpage        = 47
} ePrivateDataClass;





//---------------------------------------------------------
//      Reference styles are prefixed with 'kXRS'.
//      These styles indicate the type of buffer referenced
//      by the lpData field of an ArgBlock.
//
//      Reference flags are prefixed with 'kXRF'.
//      These flags modify the style reference to indicate to
//      attributes associated with the data reference.
//
//      Currently the only valid reference flag indicates
//      whether query results should be returned in text or
//      binary format.
//---------------------------------------------------------

enum
{
	_kXRFCantResize         = 0,
	_kXRFCanResize          = 1,
	
	_kXRFCantPurge          = 0,
	_kXRFCanPurge           = 1,
	
	_kXRFHasntResized       = 0,
	_kXRFHasResized         = 1,

	_kXRFBinary                     = 0,
	_kXRFText                       = 1
};

enum
{
	_kXRSNull                       = 0,
	_kXRSPointer            = 1,
	_kXRSHandle                     = 2,
	_kXRSFile                       = 3,
	_kXRSValue                      = 4
};

enum
{
	_kXRFResizeBit          = 0,    // These bits are going away.  They will be combined with
	_kXRFPurgeBit           = 1,    // kXRS reference styles as indicated in CQRSTYLE.H
	_kXRFResizedBit         = 2,    // Not implemented, reserved.
	_kTxResultBit           = 3,    // indicating text or binary results desired.
	_kRefCanChangeBit       = 4,    // indicating ref can change styles to accomodate results (not implemented).
	_kRefHasChangedBit      = 5,    // indicating ref was indeed changed. (not implemented)
	_kRefStyleBit           = 8             // High Byte of REFSTYLE is the ref rsStyle.  The Lo Byte is flags.
};

enum
{
	kXRFCantGrow            = 0,
	kXRFCantPurge           = 0,
	kXRFHasntResized        = 0,
	kRefCantChange          = 0,
	kRefHasntChanged        = 0,
	
	kXRFCanGrow                     = (_kXRFCanResize << _kXRFResizeBit),   // obselete
	kXRFCanPurge            = (_kXRFCanPurge << _kXRFPurgeBit),             // to become obselete.          
	kXRFHasResized          = (_kXRFHasResized << _kXRFResizedBit),
	kRefCanChange           = (1 << _kRefCanChangeBit),
	kRefHasChanged          = (1 << _kRefHasChangedBit)
};

typedef enum
{
	kXRFBinary                      = 0,
	kXRFText                        = (_kXRFText << _kTxResultBit), 
	kRefFlagsMask           = 0xFF,
	kXRFFiller                      = 100000                // force to four bytes
} eRefFlags;

typedef enum
{
	kXRSNull                        = 0, 
	kXRSPointer                     = (_kXRSPointer << _kRefStyleBit),
	kXRSHandle                      = (_kXRSHandle << _kRefStyleBit),
	kXRSFile                        = (_kXRSFile << _kRefStyleBit),
	kXRSValue                       = (_kXRSValue << _kRefStyleBit),
	kRefStyleMask           = (kXRSPointer | kXRSHandle | kXRSFile | kXRSValue),
	kXRSFiller                      = 1000          // force to two bytes
} ePMRefStyle;


//--- sPMParamBlock ---------------------------------------------------
// This parameter block is what is passed to a plug-in from PageMaker.
// for commands and queries.
//---------------------------------------------------------------------
struct sPMParamBlock;                                   // forward declaration, so that we can typedef the callback function pointer

#ifdef MACINTOSH
	typedef pascal short (*fnPMCallbackProc)(struct sPMParamBlock *);
#else
	typedef short (FAR PASCAL *fnPMCallbackProc)(struct sPMParamBlock *);
#endif

typedef struct sPMParamBlock
{

// private:  (you should not touch this field)

	void *                          magicID;

// public:      (these are for your use)
	
	void *                          pluginData;                     // For storing plug-in data between invocations. 
											// This == NULL in kPMLoad on first invocation. 
											// Your plug-in is responsible for allocating/deallocating. 
	
	unsigned short          opCode;                         // Used only in main() call from PageMaker.
	unsigned long           subCode;                        // For plug-in's use 

	const void *            requestData;
	unsigned long           requestSize;
	unsigned short          requestStyle;
	unsigned short          requestUnits;
	
	void *                          replyData;
	unsigned long           replySize;
	unsigned short          replyStyle;
	unsigned short          replyUnits;
	
	PMHandle                        errMessage;                     // Handle to null terminated string. 
											// Error text returned from plug-in, or from PageMaker 
	
	fnPMCallbackProc        pmCallback;                     // Callback function pointer

} sPMParamBlock, * sPMParamBlockPtr;
	
#ifdef __POWERPC__                                                      // For "fat" PowerMac plug-ins
enum
{
	uppEntryProcInfo = kPascalStackBased    // Callback format into PageMaker
		 | RESULT_SIZE(SIZE_CODE(sizeof(PMErr)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(sPMParamBlockPtr)))
};
#endif

#if 0
// Turned off temporarily to reconcile defines of RECT here and in
// aldink:aldgeom.h
#ifdef MACINTOSH // Structure required by the window component interface
typedef struct _RECT {
	long left;
	long top;
	long right;
	long bottom;
} RECT;
#endif
#endif

// These names are provided for backwards compatibility
// You should avoid these in new plug-ins, and consider
// upgrading your existing plug-ins to use the newer
// names.

#ifdef OLD_STYLE
#include "oldtypes.h"
#include "oldpmblk.h"
#include "oldpatch.h"
//      #define PBGetReplyData(pPB) (pPB)->replyData
	#define PBGetPluginData(pPB) (pPB)->pluginData
	#define PBSetPluginData(pPB,val) (pPB)->pluginData = (val)
	#define LPPutHANDLE     LPPutHandle
	#define kRSPointer kXRSPointer
	#define kRSHandle kXRSHandle
	#define RC PMErr
	#define PARAMBLOCK sPMParamBlock
	#define LPPARAMBLOCK sPMParamBlockPtr

#endif

#endif  // __PageMakerTypes__

// end of PageMakerTypes.h

