/*
 *--- PListMom.h ----------------------------------------------------------
 * Copyright (c) 1995-96 Adobe Systems Incorporated.  All rights reserved.
 * Created on Thu, Oct 12, 1995 @ 10:06 PM by Paul Ferguson.
 *
 * Description:  This is the utility class for query classes
 * that contain a list of information.  Refer to PListQuery
 * to see how it is used.
 *
 * Policies:
 *  (1) It makes no assumptions about the size of the list
 *      blocks, or that they are fixed or variable length.
 *  (2) If at the end of the list, it wraps around to the
 *      beginning.
 *  (3) PListMom objects do not care if the list is empty
 *      (zero members).
 *-------------------------------------------------------------------------
 */
#ifndef __PListMom__
#define __PListMom__

#ifdef __MWERKS__
#pragma once
#endif

class PListMom
{

public:

	PListMom();

	PListMom& operator=(const char * buf);		// initialize the list mom
	
	const char * Current() const { return curItemPtr; }
	short Count() const { return numItems; }
	void Reset();
	void Update(const char * ch);

private:

	short numItems;
	const char * itemsPtr;

	short curItem;
	const char * curItemPtr;
};

#endif

// end of PListMom.h
