/*
 *--- PStringListQuery.h --------------------------------------------------
 * Copyright (c) 1995-96 Adobe Systems Incorporated.  All rights reserved.
 * Created on Thu, Oct 12, 1995 @ 10:06 PM by Paul Ferguson.
 *
 * Description:  This is the base class for query classes that consist of
 * a count field (short) in the first two bytes, followed by that number
 * of strings.  The template class PStringListQuery.h contains the
 * instantiations of the various classes that are of this type.
 *-------------------------------------------------------------------------
 */
#ifndef __PStringListQuery__
#define __PStringListQuery__
#ifdef __MWERKS__
#pragma once
#endif

#include "PListQuery.h"

#include "PMTypes.h"

class PStringListQuery : public PListQuery
{

public:

	operator const char *() { return aString; }

protected:
	PStringListQuery() {}
	PStringListQuery(ePMQuery query);
	const char * aString;

	virtual void Scan();
};


template <ePMQuery QUERY>
class PStringListy : public PStringListQuery
{

public:

	PStringListy() : PStringListQuery(QUERY) { }
};

typedef PStringListy<pm_getcolornames> 			PGetColorNames;
typedef PStringListy<pm_getinknames>			PGetInkNames;
typedef PStringListy<pm_getpapersizes>			PGetPaperSizes;
typedef PStringListy<pm_getpapersources>		PGetPaperSources;
typedef PStringListy<pm_getprinterlist>			PGetPrinterList;
typedef PStringListy<pm_getprinterstyles>		PGetPrinterStyles;
typedef PStringListy<pm_getprintfeaturetitles>	PGetPrintFeatureTitles;
typedef PStringListy<pm_getprintppds>			PGetPrintPPDs;
typedef PStringListy<pm_getprintscreens>		PGetPrintScreens;
typedef PStringListy<pm_getstylenames>			PGetStyleNames;

#endif

// end of PStringListQuery.h
